[Libreoffice-commits] .: 3 commits - sfx2/source
Muthu Subramanian
sumuthu at kemper.freedesktop.org
Thu Mar 10 05:01:22 PST 2011
sfx2/source/dialog/about.cxx | 8
sfx2/source/dialog/basedlgs.cxx | 217 +++++++---------
sfx2/source/dialog/dinfdlg.cxx | 16 -
sfx2/source/dialog/dockwin.cxx | 302 ++++++++++------------
sfx2/source/dialog/mailmodel.cxx | 19 -
sfx2/source/dialog/mailmodelapi.cxx | 22 -
sfx2/source/dialog/mgetempl.cxx | 155 ++++++-----
sfx2/source/dialog/navigat.cxx | 4
sfx2/source/dialog/partwnd.cxx | 7
sfx2/source/dialog/splitwin.cxx | 261 +++++++++----------
sfx2/source/dialog/styfitem.cxx | 6
sfx2/source/dialog/styledlg.cxx | 39 +-
sfx2/source/dialog/tabdlg.cxx | 413 ++++++++++++++----------------
sfx2/source/dialog/templdlg.cxx | 240 +++++++----------
sfx2/source/dialog/tplcitem.cxx | 19 -
sfx2/source/dialog/tplpitem.cxx | 6
sfx2/source/dialog/versdlg.cxx | 4
sfx2/source/doc/doc.src | 2
sfx2/source/doc/docfac.cxx | 6
sfx2/source/doc/docfile.cxx | 36 +-
sfx2/source/doc/doctdlg.cxx | 2
sfx2/source/doc/doctempl.cxx | 483 ++++++++++++++----------------------
sfx2/source/doc/docvor.cxx | 408 ++++++++++++++----------------
sfx2/source/doc/frmdescr.cxx | 2
sfx2/source/doc/new.cxx | 10
sfx2/source/doc/objcont.cxx | 76 ++---
sfx2/source/doc/objembed.cxx | 10
sfx2/source/doc/objmisc.cxx | 217 ++++++++--------
sfx2/source/doc/objserv.cxx | 45 +--
sfx2/source/doc/objstor.cxx | 188 ++++++--------
sfx2/source/doc/objxtor.cxx | 74 ++---
sfx2/source/doc/printhelper.cxx | 11
32 files changed, 1561 insertions(+), 1747 deletions(-)
New commits:
commit be8575326897d9d9ed99d8292f397f9a78ee3140
Author: Muthu Subramanian K <sumuthu at novell.com>
Date: Thu Mar 10 18:27:19 2011 +0530
Typo fixes.
diff --git a/sfx2/source/doc/doctempl.cxx b/sfx2/source/doc/doctempl.cxx
index 389e6e1..c870b00 100644
--- a/sfx2/source/doc/doctempl.cxx
+++ b/sfx2/source/doc/doctempl.cxx
@@ -1084,7 +1084,7 @@ sal_Bool SfxDocumentTemplates::CopyFrom
String& rName /* File name of the template to be imported
as an out parameter of the (automatically
generated from the file name) logical name
- of the template * /
+ of the template */
)
/* [Description]
diff --git a/sfx2/source/doc/objcont.cxx b/sfx2/source/doc/objcont.cxx
index ecccdd4..7dcde9e 100644
--- a/sfx2/source/doc/objcont.cxx
+++ b/sfx2/source/doc/objcont.cxx
@@ -780,7 +780,7 @@ BOOL SfxObjectShell::Print
void SfxObjectShell::LoadStyles
(
SfxObjectShell &rSource /* the document template from which
- the styles are to be loaded * /
+ the styles are to be loaded */
)
/* [Description]
commit e9f6820cc8831e2bb09a05bf9b5729e7924846a2
Author: Albert Thuswaldner <albert.thuswaldner at gmail.com>
Date: Thu Mar 10 18:00:38 2011 +0530
Translations and typo fixes (3).
diff --git a/sfx2/source/doc/doc.src b/sfx2/source/doc/doc.src
index fdd1c19..ec9c5f6 100644
--- a/sfx2/source/doc/doc.src
+++ b/sfx2/source/doc/doc.src
@@ -296,7 +296,7 @@ String STR_FSET_FILTERNAME0
};
String STR_FSET_FILTERNAME1
{
- // nur 'Dokument' "ubersetzen - only translate 'Document'
+ // only translate 'Document'
Text [ en-US ] = "%PRODUCTNAME Frame Document" ;
};
String STR_TEMPL_MOVED
diff --git a/sfx2/source/doc/docfac.cxx b/sfx2/source/doc/docfac.cxx
index bbefb37..407633f 100644
--- a/sfx2/source/doc/docfac.cxx
+++ b/sfx2/source/doc/docfac.cxx
@@ -78,8 +78,8 @@ DBG_NAME(SfxObjectFactory)
struct SfxObjectFactory_Impl
{
- SfxViewFactoryArr_Impl aViewFactoryArr;// Liste von <SfxViewFactory>s
- SfxFilterArr_Impl aFilterArr; // Liste von <SFxFilter>n
+ SfxViewFactoryArr_Impl aViewFactoryArr;// List of <SfxViewFactory>s
+ SfxFilterArr_Impl aFilterArr; // List of <SFxFilter>n
ResId* pNameResId;
::rtl::OUString aServiceName;
SfxFilterContainer* pFilterContainer;
@@ -370,7 +370,7 @@ const SfxFilter* SfxObjectFactory::GetTemplateFilter() const
void SfxObjectFactory::SetDocumentTypeNameResource( const ResId& rId )
{
- DBG_ASSERT( !pImpl->pNameResId, "UI-Namensresource mehrfach gesetzt!" );
+ DBG_ASSERT( !pImpl->pNameResId, "UI-Name resource set multiple times!" );
pImpl->pNameResId = new ResId( rId );
}
diff --git a/sfx2/source/doc/doctdlg.cxx b/sfx2/source/doc/doctdlg.cxx
index 84da3f0..497dd98 100644
--- a/sfx2/source/doc/doctdlg.cxx
+++ b/sfx2/source/doc/doctdlg.cxx
@@ -159,7 +159,7 @@ IMPL_LINK( SfxDocumentTemplateDlg, OrganizeHdl, Button *, pButton )
IMPL_LINK( SfxDocumentTemplateDlg, OkHdl, Control *, pControl )
{
(void)pControl; //unused
- // pruefen, ob eine Vorlage diesen Namens existiert
+ // Test whether a template with this name exists
if(LISTBOX_ENTRY_NOTFOUND != aTemplateLb.GetEntryPos(
GetTemplateName())) {
QueryBox aQuery(this, SfxResId(MSG_CONFIRM_OVERWRITE_TEMPLATE));
diff --git a/sfx2/source/doc/doctempl.cxx b/sfx2/source/doc/doctempl.cxx
index 99388ae..389e6e1 100644
--- a/sfx2/source/doc/doctempl.cxx
+++ b/sfx2/source/doc/doctempl.cxx
@@ -314,15 +314,14 @@ static sal_Bool getTextProperty_Impl( Content& rContent,
String SfxDocumentTemplates::GetFullRegionName
(
- USHORT nIdx // Index des Bereiches
+ USHORT nIdx // Region Index
) const
-/* [Beschreibung]
+/* [Description]
- Liefert den logischen Namen eines Bereiches Plus seinem Pfad
+ Returns the logical name of a region and its path
-
- [R"uckgabewert] Referenz auf diesen Namen
+ [Return value] Reference to the Region name
*/
@@ -351,17 +350,16 @@ String SfxDocumentTemplates::GetFullRegionName
const String& SfxDocumentTemplates::GetRegionName
(
- USHORT nIdx // Index des Bereiches
+ USHORT nIdx // Region Index
) const
-/* [Beschreibung]
-
- Liefert den logischen Namen eines Bereiches
+/* [Description]
+ Returns the logical name of a region
- [R"uckgabewert]
+ [Return value]
- const String& Referenz auf diesen Namen
+ const String& Reference to the Region name
*/
{
@@ -389,17 +387,16 @@ const String& SfxDocumentTemplates::GetRegionName
USHORT SfxDocumentTemplates::GetRegionNo
(
- const String &rRegion // Name der Region
+ const String &rRegion // Region Name
) const
-/* [Beschreibung]
+/* [Description]
- Liefert den Index f"ur einen logischen Namen eines Bereiches.
+ Returns the Index for a logical Region Name.
+ [Return value]
- [R"uckgabewert]
-
- USHORT Index von 'rRegion' oder USHRT_MAX falls unbekannt
+ USHORT Index of 'rRegion' or USHRT_MAX if unknown
*/
{
@@ -422,15 +419,13 @@ USHORT SfxDocumentTemplates::GetRegionNo
USHORT SfxDocumentTemplates::GetRegionCount() const
-/* [Beschreibung]
-
- Liefert die Anzahl der Bereiche
+/* [Description]
+ Returns the number of Regions
- [R"uckgabewert]
-
- USHORT Anzahl der Bereiche
+ [Return value]
+ USHORT Number of Regions
*/
{
DocTemplLocker_Impl aLocker( *pImp );
@@ -464,20 +459,18 @@ sal_Bool SfxDocumentTemplates::IsRegionLoaded( USHORT nIdx ) const
USHORT SfxDocumentTemplates::GetCount
(
- const String& rName /* Name des Bereiches, dessen Eintrags-
- anzahl ermittelt werden soll */
+ const String& rName /* Region Name, for which the entries
+ should be counted */
) const
-/* [Beschreibung]
-
- Liefert die Anzahl der Eintr"age eines Bereiches
-
+/* [Description]
- [R"uckgabewert]
+ Number of entries in Region
- USHORT Anzahl der Eintr"age
+ [Return value]
+ USHORT Number of entries
*/
{
@@ -499,18 +492,16 @@ USHORT SfxDocumentTemplates::GetCount
USHORT SfxDocumentTemplates::GetCount
(
- USHORT nRegion /* Index des Bereiches, dessen Eintrags-
- anzahl ermittelt werden soll */
+ USHORT nRegion /* Region index whose number is
+ to be determined */
) const
-/* [Beschreibung]
+/* [Description]
- Liefert die Anzahl der Eintr"age eines Bereiches
-
-
- [R"uckgabewert] Anzahl der Eintr"age
+ Number of entries in Region
+ [Return value] Number of entries
*/
{
@@ -532,19 +523,17 @@ USHORT SfxDocumentTemplates::GetCount
const String& SfxDocumentTemplates::GetName
(
- USHORT nRegion, // Index des Bereiches, in dem der Eintrag liegt
- USHORT nIdx // Index des Eintrags
+ USHORT nRegion, // Region Index, in which the entry lies
+ USHORT nIdx // Index of the entry
) const
-/* [Beschreibung]
-
- Liefert den logischen Namen eines Eintrags eines Bereiches
+/* [Description]
+ Returns the logical name of an entry in Region
- [R"uckgabewert]
-
- const String& Name des Eintrags
+ [Return value]
+ const String& Entry Name
*/
{
@@ -575,16 +564,15 @@ const String& SfxDocumentTemplates::GetName
String SfxDocumentTemplates::GetFileName
(
- USHORT nRegion, // Index des Bereiches, in dem der Eintrag liegt
- USHORT nIdx // Index des Eintrags
+ USHORT nRegion, // Region Index, in which the entry lies
+ USHORT nIdx // Index of the entry
) const
-/* [Beschreibung]
-
- Liefert den Dateinamen eines Eintrags eines Bereiches
+/* [Description]
- [R"uckgabewert] Dateiname des Eintrags
+ Returns the file name of an entry in Region
+ [Return value] File name of the entry
*/
{
DocTemplLocker_Impl aLocker( *pImp );
@@ -612,20 +600,17 @@ String SfxDocumentTemplates::GetFileName
String SfxDocumentTemplates::GetPath
(
- USHORT nRegion, // Index des Bereiches, in dem der Eintrag liegt
- USHORT nIdx // Index des Eintrags
+ USHORT nRegion, // Region Index, in which the entry lies
+ USHORT nIdx // Index of the entry
) const
-/* [Beschreibung]
-
- Liefert den Dateinamen mit vollst"andigem Pfad zu der einem
- Eintrag zugeordneten Datei
+/* [Description]
+ Returns the file name with full path to the file assigned to an entry
- [R"uckgabewert]
-
- String Dateiname mit vollst"andigem Pfad
+ [Return value]
+ String File name with full path
*/
{
DocTemplLocker_Impl aLocker( *pImp );
@@ -649,20 +634,17 @@ String SfxDocumentTemplates::GetPath
String SfxDocumentTemplates::GetTemplatePath
(
- USHORT nRegion, // Index des Bereiches, in dem der Eintrag liegt
- const String& rLongName // logischer Name des Eintrags
+ USHORT nRegion, // Region Index, in which the entry lies
+ const String& rLongName // logical Entry Name
) const
-/* [Beschreibung]
-
- Liefert den Dateinamen mit vollst"andigem Pfad zu der einem
- Eintrag zugeordneten Datei
-
+/* [Description]
- [R"uckgabewert]
+ Returns the file name with full path to the file assigned to an entry
- String Dateiname mit vollst"andigem Pfad
+ [Return value]
+ String File name with full path
*/
{
DocTemplLocker_Impl aLocker( *pImp );
@@ -709,15 +691,13 @@ String SfxDocumentTemplates::GetDefaultTemplatePath
const String& rLongName
)
-/* [Beschreibung]
+/* [Description]
- Liefert den Standardpfad zu Dokumentvorlagen
+ Returns the default location for templates
+ [Return value]
- [R"uckgabewert]
-
- String Standardpfad zu Dokumentvorlagen
-
+ String Default location for templates
*/
{
DocTemplLocker_Impl aLocker( *pImp );
@@ -793,22 +773,17 @@ String SfxDocumentTemplates::GetDefaultTemplatePath
sal_Bool SfxDocumentTemplates::SaveDir
(
-// SfxTemplateDir& rDir // das zu speichernde Directory
+// SfxTemplateDir& rDir // Save Directory
)
-/* [Beschreibung]
-
- Speichert das Directory rDir
+/* [Description]
+ Saves the Directory rDir
- [R"uckgabewert]
-
- sal_Bool sal_False,
- Schreibfehler
-
- sal_True
- gespeichert
+ [Return value]
+ sal_Bool sal_False, Write error
+ sal_True, Saved
*/
{
@@ -819,19 +794,17 @@ sal_Bool SfxDocumentTemplates::SaveDir
void SfxDocumentTemplates::NewTemplate
(
- USHORT nRegion, /* Index des Bereiches, in dem die Vorlage
- angelegt werden soll */
+ USHORT nRegion, /* Region Index, in which the template
+ should be applied */
- const String& rLongName, // logischer Name der neuen Vorlage
- const String& rFileName // Dateiname der neuen Vorlage
+ const String& rLongName, // logical name of the new template
+ const String& rFileName // File name of the new template
)
-/* [Beschreibung]
-
- Eintragen einer neuen Dokumentvorlage in die Verwaltungsstrukturen
- Das "Uberschreiben einer Vorlage gleichen Namens wird
- verhindert (!! Fehlermeldung)
+/* [Description]
+ Submit a new template in the administrative structures
+ overwriting a template of the same name is prevented (! Error message)
*/
{
@@ -863,26 +836,23 @@ void SfxDocumentTemplates::NewTemplate
sal_Bool SfxDocumentTemplates::CopyOrMove
(
- USHORT nTargetRegion, // Index des Zielbereiches
- USHORT nTargetIdx, // Index Zielposition
- USHORT nSourceRegion, // Index des Quellbereiches
- USHORT nSourceIdx, /* Index der zu kopierenden / zu verschiebenden
- Dokumentvorlage */
- sal_Bool bMove // kopieren / verschieben
+ USHORT nTargetRegion, // Target Region Index
+ USHORT nTargetIdx, // Target position Index
+ USHORT nSourceRegion, // Source Region Index
+ USHORT nSourceIdx, /* Index to be copied / to moved template */
+ sal_Bool bMove // Copy / Move
)
-/* [Beschreibung]
+/* [Description]
- Kopieren oder Verschieben einer Dokumentvorlage
+ Copy or move a document template
- [R"uckgabewert]
+ [Return value]
- sal_Bool sal_True
- Aktion konnte ausgef"uhrt werden
+ sal_Bool sal_True, Action could be performed
+ sal_False, Action could not be performed
- sal_False
- Aktion konnte nicht ausgef2uhrt werden
- [Querverweise]
+ [Cross-references]
<SfxDocumentTemplates::Move(USHORT,USHORT,USHORT,USHORT)>
<SfxDocumentTemplates::Copy(USHORT,USHORT,USHORT,USHORT)>
@@ -965,8 +935,8 @@ sal_Bool SfxDocumentTemplates::CopyOrMove
return sal_True;
}
- // --**-- wenn aktuell das File geoeffnet ist,
- // muss es hinterher wieder geoeffnet werden
+ // --**-- if the current file is opened,
+ // it must be re-opened afterwards.
return sal_False;
}
@@ -975,27 +945,22 @@ sal_Bool SfxDocumentTemplates::CopyOrMove
sal_Bool SfxDocumentTemplates::Move
(
- USHORT nTargetRegion, // Index des Zielbereiches
- USHORT nTargetIdx, // Index Zielposition
- USHORT nSourceRegion, // Index des Quellbereiches
- USHORT nSourceIdx /* Index der zu kopierenden / zu verschiebenden
- Dokumentvorlage */
+ USHORT nTargetRegion, // Target Region Index
+ USHORT nTargetIdx, // Target position Index
+ USHORT nSourceRegion, // Source Region Index
+ USHORT nSourceIdx /* Index to be copied / to moved template */
)
-/* [Beschreibung]
+/* [Description]
- Verschieben einer Dokumentvorlage
+ Moving a template
+ [Return value]
- [R"uckgabewert]
+ sal_Bool sal_True, Action could be performed
+ sal_False, Action could not be performed
- sal_Bool sal_True
- Aktion konnte ausgef"uhrt werden
-
- sal_False
- Aktion konnte nicht ausgef2uhrt werden
-
- [Querverweise]
+ [Cross-references]
<SfxDocumentTemplates::CopyOrMove(USHORT,USHORT,USHORT,USHORT,sal_Bool)>
*/
@@ -1010,27 +975,22 @@ sal_Bool SfxDocumentTemplates::Move
sal_Bool SfxDocumentTemplates::Copy
(
- USHORT nTargetRegion, // Index des Zielbereiches
- USHORT nTargetIdx, // Index Zielposition
- USHORT nSourceRegion, // Index des Quellbereiches
- USHORT nSourceIdx /* Index der zu kopierenden / zu verschiebenden
- Dokumentvorlage */
+ USHORT nTargetRegion, // Target Region Index
+ USHORT nTargetIdx, // Target position Index
+ USHORT nSourceRegion, // Source Region Index
+ USHORT nSourceIdx /* Index to be copied / to moved template */
)
-/* [Beschreibung]
-
- Kopieren einer Dokumentvorlage
+/* [Description]
+ Copying a template
- [R"uckgabewert]
+ [Return value]
- sal_Bool sal_True
- Aktion konnte ausgef"uhrt werden
+ sal_Bool sal_True, Action could be performed
+ sal_False, Action could not be performed
- sal_False
- Aktion konnte nicht ausgef"uhrt werden
-
- [Querverweise]
+ [Cross-references]
<SfxDocumentTemplates::CopyOrMove(USHORT,USHORT,USHORT,USHORT,sal_Bool)>
*/
@@ -1046,29 +1006,22 @@ sal_Bool SfxDocumentTemplates::Copy
sal_Bool SfxDocumentTemplates::CopyTo
(
- USHORT nRegion, /* Bereich der Vorlage, die exportiert werden
- soll */
- USHORT nIdx, /* Index der Vorlage, die exportiert werden
- soll */
- const String& rName /* Dateiname, unter dem die Vorlage angelegt
- werden soll */
+ USHORT nRegion, // Region of the template to be exported
+ USHORT nIdx, // Index of the template to be exported
+ const String& rName /* File name under which the template is to
+ be created */
) const
-/* [Beschreibung]
-
- Exportieren einer Dokumentvorlage in das Dateisystem
-
-
- [R"uckgabewert]
+/* [Description]
- sal_Bool sal_True
- Aktion konnte ausgef"uhrt werden
+ Exporting a template into the file system
- sal_False
- Aktion konnte nicht ausgef"uhrt werden
+ [Return value]
+ sal_Bool sal_True, Action could be performed
+ sal_False, Action could not be performed
- [Querverweise]
+ [Cross-references]
<SfxDocumentTemplates::CopyFrom(USHORT,USHORT,String&)>
*/
@@ -1125,29 +1078,25 @@ sal_Bool SfxDocumentTemplates::CopyTo
sal_Bool SfxDocumentTemplates::CopyFrom
(
- USHORT nRegion, /* Bereich, in den die Vorlage importiert
- werden soll */
- USHORT nIdx, // Index der neuen Vorlage in diesem Bereich
- String& rName /* Dateiname der Vorlage, die importiert
- werden soll, als out-Parameter der (auto-
- matisch aus dem Dateinamen generierte)
- logische Name der Vorlage */
+ USHORT nRegion, /* Region in which the template is to be
+ imported */
+ USHORT nIdx, // Index of the new template in this Region
+ String& rName /* File name of the template to be imported
+ as an out parameter of the (automatically
+ generated from the file name) logical name
+ of the template * /
)
-/* [Beschreibung]
+/* [Description]
- Importieren einer Dokumentvorlage aus dem Dateisystem
+ Import a template from the file system
+ [Return value] Sucess (sal_True) or serfpTargetDirectory->GetContent());
- [R"uckgabewert] Erfolg (sal_True) oder Mi"serfpTargetDirectory->GetContent());
+ sal_Bool sal_True, Action could be performed
+ sal_False, Action could not be performed
- sal_Bool sal_True
- Aktion konnte ausgef"uhrt werden
-
- sal_False
- Aktion konnte nicht ausgef"uhrt werden
-
- [Querverweise]
+ [Cross-references]
<SfxDocumentTemplates::CopyTo(USHORT,USHORT,const String&)>
*/
@@ -1276,26 +1225,21 @@ sal_Bool SfxDocumentTemplates::CopyFrom
sal_Bool SfxDocumentTemplates::Delete
(
- USHORT nRegion, // Index des Bereiches
- USHORT nIdx /* Index des Eintrags oder USHRT_MAX,
- wenn ein Verzeichnis gemeint ist. */
+ USHORT nRegion, // Region Index
+ USHORT nIdx /* Index of the entry or USHRT_MAX,
+ if a directory is meant. */
)
-/* [Beschreibung]
-
- "oschen eines Eintrags oder eines Verzeichnisses
+/* [Description]
+ Deleting an entry or a directory
- [R"uckgabewert]
+ [Return value]
- sal_Bool sal_True
- Aktion konnte ausgef"uhrt werden
+ sal_Bool sal_True, Action could be performed
+ sal_False, Action could not be performed
- sal_False
- Aktion konnte nicht ausgef"uhrt werden
-
-
- [Querverweise]
+ [Cross-references]
<SfxDocumentTemplates::InsertDir(const String&,USHORT)>
<SfxDocumentTemplates::KillDir(SfxTemplateDir&)>
@@ -1346,24 +1290,20 @@ sal_Bool SfxDocumentTemplates::Delete
sal_Bool SfxDocumentTemplates::InsertDir
(
- const String& rText, // der logische Name des neuen Bereiches
- USHORT nRegion // Index des Bereiches
+ const String& rText, // the logical name of the new Region
+ USHORT nRegion // Region Index
)
-/* [Beschreibung]
-
- Einf"ugen eines Verzeichnisses
+/* [Description]
+ Insert an index
- [R"uckgabewert]
+ [Return value]
- sal_Bool sal_True
- Aktion konnte ausgef"uhrt werden
+ sal_Bool sal_True, Action could be performed
+ sal_False, Action could not be performed
- sal_False
- Aktion konnte nicht ausgef"uhrt werden
-
- [Querverweise]
+ [Cross-references]
<SfxDocumentTemplates::KillDir(SfxTemplateDir&)>
<SfxDocumentTemplates::SaveDir(SfxTemplateDir&)>
@@ -1401,23 +1341,19 @@ sal_Bool SfxDocumentTemplates::InsertDir
sal_Bool SfxDocumentTemplates::SetName
(
const String& rName, // Der zu setzende Name
- USHORT nRegion, // Index des Bereiches
- USHORT nIdx /* Index des Eintrags oder USHRT_MAX,
- wenn ein Verzeichnis gemeint ist. */
+ USHORT nRegion, // Region Index
+ USHORT nIdx /* Index of the entry oder USHRT_MAX,
+ if a directory is meant. */
)
-/* [Beschreibung]
-
- "Andern des Namens eines Eintrags oder eines Verzeichnisses
-
+/* [Description]
- [R"uckgabewert]
+ Change the name of an entry or a directory
- sal_Bool sal_True
- Aktion konnte ausgef"uhrt werden
+ [Return value]
- sal_False
- Aktion konnte nicht ausgef"uhrt werden
+ sal_Bool sal_True, Action could be performed
+ sal_False, Action could not be performed
*/
@@ -1478,24 +1414,18 @@ sal_Bool SfxDocumentTemplates::SetName
sal_Bool SfxDocumentTemplates::Rescan()
-/* [Beschreibung]
+/* [Description]
- Abgleich des Verwaltungsdaten mit dem aktuellen Zustand auf der Platte.
- Die logischen Namen, zu denen keine Datei mit existiert, werden aus
- der Verwaltungsstruktur entfernt; Dateien, zu denen kein Eintrag
- existiert, werden aufgenommen.
+ Comparison of administrative data with the current state on disk.
+ The logical name for which no file exists, will be removed from the
+ administrative structure. Files for which no record exists will be included.
+ [Return value]
- [R"uckgabewert]
+ sal_Bool sal_True, Action could be performed
+ sal_False, Action could not be performed
- sal_Bool sal_True
- Aktion konnte ausgef"uhrt werden
-
- sal_False
- Aktion konnte nicht ausgef"uhrt werden
-
-
- [Querverweise]
+ [Cross-references]
<SfxTemplateDir::Scan(sal_Bool bDirectory, sal_Bool bSave)>
<SfxTemplateDir::Freshen(const SfxTemplateDir &rNew)>
@@ -1513,21 +1443,19 @@ sal_Bool SfxDocumentTemplates::Rescan()
SfxObjectShellRef SfxDocumentTemplates::CreateObjectShell
(
- USHORT nRegion, // Index des Bereiches
- USHORT nIdx // Index des Eintrags
+ USHORT nRegion, // Region Index
+ USHORT nIdx // Index of the entry
)
-/* [Beschreibung]
+/* [Description]
- Zugriff auf die DokumentShell eines Eintrags
+ Access to the document shell of an entry
+ [Return value]
- [R"uckgabewert]
+ SfxObjectShellRef Referece to the ObjectShell
- SfxObjectShellRef Referenz auf die ObjectShell
-
-
- [Querverweise]
+ [Cross-references]
<SfxTemplateDirEntry::CreateObjectShell()>
<SfxDocumentTemplates::DeleteObjectShell(USHORT, USHORT)>
@@ -1555,24 +1483,20 @@ SfxObjectShellRef SfxDocumentTemplates::CreateObjectShell
sal_Bool SfxDocumentTemplates::DeleteObjectShell
(
- USHORT nRegion, // Index des Bereiches
- USHORT nIdx // Index des Eintrags
+ USHORT nRegion, // Region Index
+ USHORT nIdx // Index of the entry
)
-/* [Beschreibung]
-
- Freigeben der ObjectShell eines Eintrags
+/* [Description]
+ Releasing the ObjectShell of an entry
- [R"uckgabewert]
+ [Return value]
- sal_Bool sal_True
- Aktion konnte ausgef"uhrt werden
+ sal_Bool sal_True, Action could be performed
+ sal_False, Action could not be performed
- sal_False
- Aktion konnte nicht ausgef"uhrt werden
-
- [Querverweise]
+ [Cross-references]
<SfxTemplateDirEntry::DeleteObjectShell()>
<SfxDocumentTemplates::CreateObjectShell(USHORT, USHORT)>
@@ -1600,27 +1524,21 @@ sal_Bool SfxDocumentTemplates::DeleteObjectShell
sal_Bool SfxDocumentTemplates::GetFull
(
- const String &rRegion, // Der Name des Bereiches
- const String &rName, // Der Name der Vorlage
- String &rPath // Out: Pfad + Dateiname
+ const String &rRegion, // Region Name
+ const String &rName, // Template Name
+ String &rPath // Out: Path + File name
)
-/* [Beschreibung]
-
- Liefert Pfad + Dateiname zu der durch rRegion und rName bezeichneten
- Vorlage
-
+/* [Description]
- [R"uckgabewert]
+ Returns Path + File name of the template specified by rRegion and rName.
- sal_Bool sal_True
- Aktion konnte ausgef"uhrt werden
+ [Return value]
- sal_False
- Aktion konnte nicht ausgef"uhrt werden
+ sal_Bool sal_True, Action could be performed
+ sal_False, Action could not be performed
-
- [Querverweise]
+ [Cross-references]
<SfxDocumentTemplates::GetLogicNames(const String&,String&,String&)>
*/
@@ -1662,26 +1580,21 @@ sal_Bool SfxDocumentTemplates::GetFull
sal_Bool SfxDocumentTemplates::GetLogicNames
(
- const String &rPath, // vollst"andiger Pfad zu der Vorlage
- String &rRegion, // Out: der Bereichsname
- String &rName // Out: der Vorlagenname
+ const String &rPath, // Full Path to the template
+ String &rRegion, // Out: Region name
+ String &rName // Out: Template name
) const
-/* [Beschreibung]
-
- Liefert Pfad und logischen Namen zu der durch rPath bezeichneten
- Vorlage
-
- [R"uckgabewert]
+/* [Description]
- sal_Bool sal_True
- Aktion konnte ausgef"uhrt werden
+ Returns and logical path name to the template specified by rPath
- sal_False
- Aktion konnte nicht ausgef"uhrt werden
+ [Return value]
+ sal_Bool sal_True, Action could be performed
+ sal_False, Action could not be performed
- [Querverweise]
+ [Cross-references]
<SfxDocumentTemplates::GetFull(const String&,const String&,DirEntry&)>
*/
@@ -1735,9 +1648,9 @@ sal_Bool SfxDocumentTemplates::GetLogicNames
SfxDocumentTemplates::SfxDocumentTemplates()
-/* [Beschreibung]
+/* [Description]
- Konstruktor
+ Constructor
*/
{
if ( !gpTemplateData )
@@ -1750,7 +1663,7 @@ SfxDocumentTemplates::SfxDocumentTemplates()
void SfxDocumentTemplates::Construct()
-// verz"ogerter Aufbau der Verwaltungsdaten
+// Delayed build-up of administrative data
{
}
@@ -1759,10 +1672,10 @@ void SfxDocumentTemplates::Construct()
SfxDocumentTemplates::~SfxDocumentTemplates()
-/* [Beschreibung]
+/* [Description]
- Destruktor
- Freigeben der Verwaltungsdaten
+ Destructor
+ Release of administrative data
*/
{
@@ -1922,7 +1835,7 @@ BOOL DocTempl_EntryData_Impl::DeleteObjectShell()
{
if( mxObjShell->IsModified() )
{
- //Hier speichern wir auch, falls die Vorlage in Bearbeitung ist...
+ // Here we also save, if the Template is being processed ...
bRet = sal_False;
if ( mbIsOwner )
diff --git a/sfx2/source/doc/docvor.cxx b/sfx2/source/doc/docvor.cxx
index adc3e0d..5fe34b1 100644
--- a/sfx2/source/doc/docvor.cxx
+++ b/sfx2/source/doc/docvor.cxx
@@ -231,8 +231,8 @@ SfxOrganizeDlg_Impl::SfxOrganizeDlg_Impl( SfxTemplateOrganizeDlg* pParent,
const_cast< SfxDocumentTemplates* >( aMgr.GetTemplates() )->Update( sal_True /* be smart */ );
// this const_cast is a hack - but the alternative would be to
// * have a method which returns the templates non-const
- // * use a new SfxDocumentTemplates instance for the update (knowing that they all share the same
- // implementation class)
+ // * use a new SfxDocumentTemplates instance for the update
+ // (knowing that they all share the same implementation class)
// * always work with an own instance, even if we get only NULL in this ctor
}
@@ -325,12 +325,12 @@ void SfxOrganizeDlg_Impl::InitBitmaps( void )
//=========================================================================
-BOOL QueryDelete_Impl(Window *pParent, // Parent der QueryBox
+BOOL QueryDelete_Impl(Window *pParent, // Parent to QueryBox
USHORT nId, // Resource Id
- const String &rTemplateName) // Name der zu l"oschenden Vorlage
-/* [Beschreibung]
+ const String &rTemplateName) // Name of template to be deleted
+/* [Description]
- "oschabfrage
+ Delete Query
*/
{
@@ -345,10 +345,9 @@ BOOL QueryDelete_Impl(Window *pParent, // Parent der QueryBox
void ErrorDelete_Impl(Window *pParent, const String &rName, sal_Bool bFolder = sal_False )
-/* [Beschreibung]
-
- Benutzerinformation, da"s die Vorlage rName nicht gel"oscht werden konnte
+/* [Description]
+ User information that the template rName could not be deleted.
*/
{
if ( bFolder )
@@ -367,10 +366,9 @@ void ErrorDelete_Impl(Window *pParent, const String &rName, sal_Bool bFolder = s
//=========================================================================
-/* [Beschreibung]
-
- Implementierungsklasse; Referenzklasse f"ur USHORT-Array
+/* [Description]
+ Implementation class, the benchmark for USHORT-Array
*/
struct ImpPath_Impl
@@ -404,12 +402,11 @@ ImpPath_Impl::ImpPath_Impl( const ImpPath_Impl& rCopy ) :
//==========================================================================
-/* [Beschreibung]
-
- Implementierungsklasse; Darstellung einer Position in der Outline-
- Listbox als USHORT-Array; dieses beschreibt die Position jeweil
- als relative Postion zum "ubergeordneten Eintrag
+/* [Description]
+ Implementation class, presentation of a position in the Outline-
+ Listbox ass USHORT-Array, this describes the position of each as
+ Postions relative to the parent entry
*/
class Path
{
@@ -468,25 +465,24 @@ SvLBoxEntry *GetIndices_Impl(SvLBox *pBox,
SvLBoxEntry *pEntry,
USHORT &rRegion,
USHORT &rOffset)
-/* [Beschreibung]
+/* [Description]
- Bereich und Position innerhalb eines Bereiches f"ur eine
- Dokumentvorlage wird ermittelt.
+ Region and position within a range for a template is determined.
[Parameter]
- SvLBox *pBox Listbox, an der das Ereignis auftrat
- SvLBoxEntry *pEntry Eintrag, dessen Position ermittelt werden soll
- USHORT &rRegion der Bereich innerhalb der Bereiche der
- Dokumentvorlagen (Out-Parameter)
- USHORT &rOffset die Position innerhalb des Bereiches
- Dokumentvorlagen (Out-Parameter)
+ SvLBox *pBox Listbox where the event occurred
+ SvLBoxEntry *pEntry Entry whose position is to be determined
+ USHORT &rRegion the region within the region of the
+ document template (Out-Parameter)
+ USHORT &rOffset the position within the region of the
+ document template (Out-Parameter)
- [Querverweise]
- <class Path> (unter Umst"anden kann auf diese Funktion zugunsten
- von Path verzichtet werden.)
+ [Cross-references]
+ <class Path> (in certain circumstances this function can also be
+ dispensed in favor of the Path)
*/
{
@@ -531,24 +527,24 @@ BOOL SfxOrganizeListBox_Impl::MoveOrCopyTemplates(SvLBox *pSourceBox,
SvLBoxEntry *&pNewParent,
ULONG &rIdx,
BOOL bCopy)
-/* [Beschreibung]
+/* [Description]
- Verschieben oder Kopieren von Dokumentvorlagen
+ Move or copy a document templates
[Parameter]
- SvLBox *pSourceBox Quell-Listbox, an der das Ereignis auftrat
- SvLBoxEntry *pSource Quell-Eintrag, der kopiert / verschoben werden soll
- SvLBoxEntry* pTarget Ziel-Eintrag, auf den verschoben werden soll
- SvLBoxEntry *&pNewParent der Parent der an der Zielposition erzeugten
- Eintrags (Out-Parameter)
- ULONG &rIdx Index des Zieleintrags
- BOOL bCopy Flag f"ur Kopieren / Verschieben
+ SvLBox *pSourceBox Source Listbox, at which the event occurred
+ SvLBoxEntry* pTarget Target entry, to where it will be moved
+ SvLBoxEntry *pSource Source entry, to be copied / moved
+ SvLBoxEntry *&pNewParent the parent of the target position generated
+ at entry (out parameter)
+ ULONG &rIdx Index of the target entry
+ BOOL bCopy Flag for Copy / Move
- [Returnwert] BOOL: Erfolg oder Mi"serfolg
+ [Return value] BOOL: Success or failure
- [Querverweise]
+ [Cross-references]
<SfxOrganizeListBox_Impl::MoveOrCopyContents(SvLBox *pSourceBox,
SvLBoxEntry *pSource,
@@ -622,24 +618,24 @@ BOOL SfxOrganizeListBox_Impl::MoveOrCopyContents(SvLBox *pSourceBox,
SvLBoxEntry *&pNewParent,
ULONG &rIdx,
BOOL bCopy)
-/* [Beschreibung]
+/* [Description]
- Verschieben oder Kopieren von Dokumentinhalten
+ Move or copy document contents
[Parameter]
- SvLBox *pSourceBox Quell-Listbox, an der das Ereignis auftrat
- SvLBoxEntry *pSource Quell-Eintrag, der kopiert / verschoben werden soll
- SvLBoxEntry* pTarget Ziel-Eintrag, auf den verschoben werden soll
- SvLBoxEntry *&pNewParent der Parent der an der Zielposition erzeugten
- Eintrags (Out-Parameter)
- ULONG &rIdx Index des Zieleintrags
- BOOL bCopy Flag f"ur Kopieren / Verschieben
+ SvLBox *pSourceBox Source Listbox, at which the event occurred
+ SvLBoxEntry* pTarget Target entry, to where it will be moved
+ SvLBoxEntry *pSource Source entry, to be copied / moved
+ SvLBoxEntry *&pNewParent the parent of the target position generated
+ at entry (out parameter)
+ ULONG &rIdx Index of the target entry
+ BOOL bCopy Flag for Copy / Move
- [Returnwert] BOOL: Erfolg oder Mi"serfolg
+ [Return value] BOOL: Success or failure
- [Querverweise]
+ [Cross-references]
<SfxOrganizeListBox_Impl::MoveOrCopyTemplates(SvLBox *pSourceBox,
SvLBoxEntry *pSource,
@@ -691,16 +687,16 @@ BOOL SfxOrganizeListBox_Impl::MoveOrCopyContents(SvLBox *pSourceBox,
*aSourceDoc, aSource[nSLevel+1],
aSource[nSLevel+2], aSource[nSLevel+3],
p[0], p[1], p[2], nIdxDeleted);
- // Positionskorrektur auswerten
- // a = Dokumentinhalt
- // b = Position Sub-Inhalt 1
- // c = Position Sub-Inhalt 2
- // doppelte Eintraege loeschen
+ // Evaluate Position correction
+ // a = Document content
+ // b = Position Sub-content 1
+ // c = Position Sub-content 2
+ // Delete duplicate entries
if(bOk)
{
SvLBoxEntry *pParentIter = pTarget;
- // bis auf die DokumentEbene nach oben als
- // allgemeiner Bezugspunkt
+ // Up to the document level as
+ // the general reference point
while(GetModel()->GetDepth(pParentIter) != nTLevel)
pParentIter = GetParent(pParentIter);
if(pParentIter->HasChildsOnDemand() &&
@@ -712,10 +708,10 @@ BOOL SfxOrganizeListBox_Impl::MoveOrCopyContents(SvLBox *pSourceBox,
while(i < 2 && p[i+1] != INDEX_IGNORE)
{
pChildIter = FirstChild(pParentIter);
- // bis zum Index der aktuellen Ebene
+ // To the index of the current level
for(USHORT j = 0; j < p[i]; ++j)
pChildIter = NextSibling(pChildIter);
- // gfs Fuellen bei Items onDemand
+ // If possible, fill in Items onDemand
++i;
if(p[i+1] != INDEX_IGNORE &&
pChildIter->HasChildsOnDemand() &&
@@ -733,8 +729,8 @@ BOOL SfxOrganizeListBox_Impl::MoveOrCopyContents(SvLBox *pSourceBox,
if(!bCopy)
pSourceBox->GetModel()->Remove(pSource);
}
- // Geloeschte Eintraege entfernen
- // (kann durch Ueberschreiben geschehen)
+ // Remove deleted items
+ // (can be done by overwriting)
if(nIdxDeleted != INDEX_IGNORE)
{
pChildIter = FirstChild(pParentIter);
@@ -770,23 +766,23 @@ BOOL SfxOrganizeListBox_Impl::NotifyMoving(SvLBoxEntry *pTarget,
SvLBoxEntry *&pNewParent,
ULONG &rIdx)
-/* [Beschreibung]
+/* [Description]
- Benachrichtigung, da"s ein Eintrag verschoben werden soll
+ Notification that an item will be moved.
(SV-Handler)
[Parameter]
- SvLBoxEntry* pTarget Ziel-Eintrag, auf den verschoben werden soll
- SvLBoxEntry *pSource Quell-Eintrag, der verschoben werden soll
- SvLBoxEntry *&pNewParent der Parent der an der Zielposition erzeugten
- Eintrags (Out-Parameter)
- ULONG &rIdx Index des Zieleintrags
+ SvLBoxEntry* pTarget Target entry, to where it will be moved
+ SvLBoxEntry *pSource Source entry, to be moved
+ SvLBoxEntry *&pNewParent the parent of the target position generated
+ at entry (out parameter)
+ ULONG &rIdx Index of the target entry
- [Returnwert] BOOL: Erfolg oder Mi"serfolg
+ [Return value] BOOL: Sucess or failure
- [Querverweise]
+ [Cross-references]
<SfxOrganizeListBox_Impl::MoveOrCopyTemplates(SvLBox *pSourceBox,
SvLBoxEntry *pSource,
@@ -830,23 +826,22 @@ BOOL SfxOrganizeListBox_Impl::NotifyCopying(SvLBoxEntry *pTarget,
SvLBoxEntry* pSource,
SvLBoxEntry *&pNewParent,
ULONG &rIdx)
-/* [Beschreibung]
+/* [Description]
- Benachrichtigung, da"s ein Eintrag kopiert werden soll
+ Notification that an item will be moved.
(SV-Handler)
[Parameter]
- SvLBoxEntry* pTarget Ziel-Eintrag, auf den kopiert werden soll
- SvLBoxEntry *pSource Quell-Eintrag, der kopiert werden soll
- SvLBoxEntry *&pNewParent der Parent der an der Zielposition erzeugten
- Eintrags (Out-Parameter)
- ULONG &rIdx Index des Zieleintrags
-
+ SvLBoxEntry* pTarget Target entry, to where it will be copied
+ SvLBoxEntry *pSource Source entry, to be copied
+ SvLBoxEntry *&pNewParent the parent of the target position generated
+ at entry (out parameter)
+ ULONG &rIdx Index of the target entry
- [Returnwert] BOOL: Erfolg oder Mi"serfolg
+ [Return value] BOOL: Sucess or failure
- [Querverweise]
+ [Cross-references]
<SfxOrganizeListBox_Impl::MoveOrCopyTemplates(SvLBox *pSourceBox,
SvLBoxEntry *pSource,
@@ -886,12 +881,12 @@ BOOL SfxOrganizeListBox_Impl::NotifyCopying(SvLBoxEntry *pTarget,
BOOL SfxOrganizeListBox_Impl::EditingEntry( SvLBoxEntry* pEntry, Selection& )
-/* [Beschreibung]
+/* [Description]
- Nachfrage, ob ein Eintrag editierbar ist
+ Check whether an item can be edited
(SV-Handler)
- [Querverweise]
+ [Cross-references]
<SfxOrganizeListBox_Impl::EditedEntry(SvLBoxEntry* pEntry, const String& rText)>
*/
@@ -909,23 +904,23 @@ BOOL SfxOrganizeListBox_Impl::EditingEntry( SvLBoxEntry* pEntry, Selection& )
BOOL SfxOrganizeListBox_Impl::EditedEntry(SvLBoxEntry* pEntry, const String& rText)
-/* [Beschreibung]
+/* [Description]
- Der Name eines Eintrags wurde bearbeitet; ist der eingegebene Name
- ein g"ultiger Name ("ange > 0), wird das Model aktualisiert.
+ The name of an entry has been processed, if the name you entered is a
+ valid name (length> 0) then the model is updated.
(SV-Handler)
- [Returnwert]
+ [Return value]
- BOOL TRUE: der Name soll in der Anzeige ge"andert werden
- FALSE:der Name soll nicht ge"andert werden
+ BOOL TRUE: The name in the display should be changed
+ FALSE: The name should not be changed
- [Querverweise]
+ [Cross-references]
<SfxOrganizeListBox_Impl::EditingEntry(SvLBoxEntry* pEntry, const String& rText)>
*/
{
- DBG_ASSERT(pEntry, "kein Entry selektiert");
+ DBG_ASSERT(pEntry, "No Entry selected");
delete pDlg->pSuspend;
pDlg->pSuspend = NULL;
SvLBoxEntry* pParent = GetParent(pEntry);
@@ -1082,14 +1077,14 @@ void SfxOrganizeListBox_Impl::DragFinished( sal_Int8 nDropAction )
inline USHORT SfxOrganizeListBox_Impl::GetDocLevel() const
-/* [Beschreibung]
+/* [Description]
- Ermittelt, auf welche Ebene sich Dokumente befinden (unterschiedlich
- in der Dokumentvorlagensicht und der Dokumentensicht)
+ Determines on which level there are documents (in the template view or
+ the document view)
- [Returnwert]
+ [Return value]
- USHORT Die Ebene der Dokumente
+ USHORT Document level
*/
@@ -1101,20 +1096,19 @@ inline USHORT SfxOrganizeListBox_Impl::GetDocLevel() const
SfxObjectShellRef SfxOrganizeListBox_Impl::GetObjectShell(const Path &rPath)
-/* [Beschreibung]
+/* [Description]
- Zugriff auf die ObjectShell, die dem aktuellen Eintrag zugeordnet
- ist.
+ Access to the ObjectShell to which the current entry is connected.
[Parameter]
- const Path &rPath Beschreibung des aktuellen Eintrags
+ const Path &rPath Description of the current entry
- [Returnwert]
+ [Return value]
- SfxObjectShellRef Referenz auf die ObjectShell
+ SfxObjectShellRef Reference to the ObjectShell
- [Querverweise]
+ [Cross-references]
<class Path>
@@ -1133,17 +1127,14 @@ SfxObjectShellRef SfxOrganizeListBox_Impl::GetObjectShell(const Path &rPath)
void SfxOrganizeListBox_Impl::RequestingChilds( SvLBoxEntry* pEntry )
-/* [Beschreibung]
+/* [Description]
- Aufforderung, der Childs eines Eintrags einzuf"ugen
- ist.
+ Sent to the Childs of an entry that is going to be inserted.
(SV-Handler)
[Parameter]
- SvLBoxEntry* pEntry der Eintrag, dessen Childs erfragt werden
-
-
+ SvLBoxEntry* pEntry the entry whose Childs is requested
*/
{
@@ -1151,9 +1142,11 @@ void SfxOrganizeListBox_Impl::RequestingChilds( SvLBoxEntry* pEntry )
{
WaitObject aWaitCursor( this );
+ // Choose the correct mask color dependent from eColorMode. This
+ // must be adopted if we change the mask color for normal images, too!
Color aMaskColor( COL_LIGHTMAGENTA );
- // hier sind alle initial eingefuegt
+ // Here are all the initial inserted
SfxErrorContext aEc(ERRCTX_SFX_CREATEOBJSH, pDlg->pDialog);
if(VIEW_TEMPLATES == GetViewType() && 0 == GetModel()->GetDepth(pEntry))
{
@@ -1200,14 +1193,11 @@ void SfxOrganizeListBox_Impl::RequestingChilds( SvLBoxEntry* pEntry )
long SfxOrganizeListBox_Impl::ExpandingHdl()
-/* [Beschreibung]
-
- SV-Handler, der nach dem und vor dem Aufklappen eines Eintrags
- gerufen wird.
- Wird verwendet, um gfs. die ObjectShell wieder zu schlie"sen;
- die Eintr"age mit den Inhalten dieser Shell werden ebenfalls
- entfernt.
+/* [Description]
+ SV-handler, before and after the unfolding of an entry is called.
+ Used if possibly to close the ObjectShell again, the entries with the
+ contents of this shell are also removed.
*/
{
@@ -1219,12 +1209,12 @@ long SfxOrganizeListBox_Impl::ExpandingHdl()
(eViewType == VIEW_TEMPLATES && nLevel == 1))
{
Path aPath(this, pEntry);
- // Beim Schliessen des Files die ObjectShell freigeben
+ // Release ObjectShell when closing the files
if(eViewType == VIEW_FILES && nLevel == 0)
pMgr->DeleteObjectShell(aPath[0]);
else
pMgr->DeleteObjectShell(aPath[0], aPath[1]);
- // alle SubEntries loeschen
+ // Delete all SubEntries
SvLBoxEntry *pToDel = SvLBox::GetEntry(pEntry, 0);
while(pToDel)
{
@@ -1241,18 +1231,18 @@ long SfxOrganizeListBox_Impl::ExpandingHdl()
BOOL SfxOrganizeListBox_Impl::IsUniqName_Impl(const String &rText,
SvLBoxEntry* pParent, SvLBoxEntry *pEntry) const
-/* [Beschreibung]
+/* [Description]
- Pr"uft, ob eine Name auf seiner Ebene eindeutig ist.
+ Checks whether a name is unique at its level.
[Parameter]
- const String & Name des zu suchenden Eintrags
- SvLBoxEntry* pSibling Geschwister (bezeichnet die Ebene)
+ const String & Name of the search entry
+ SvLBoxEntry* pSibling Siblings (referred to the level)
- [Returnwert]
+ [Return value]
- BOOL TRUE, wenn der Name eindeutig ist, sonst FALSE
+ BOOL TRUE, if the name is unique, otherwise FALSE
*/
{
@@ -1331,9 +1321,9 @@ SfxOrganizeListBox_Impl::SfxOrganizeListBox_Impl
pDlg ( pArgDlg ),
eViewType ( eType )
-/* [Beschreibung]
+/* [Description]
- Konstruktor SfxOrganizeListBox
+ Constructor SfxOrganizeListBox
*/
@@ -1380,15 +1370,14 @@ IMPL_LINK( SfxOrganizeListBox_Impl, OnAsyncExecuteDrop, ExecuteDropEvent*, pEven
void SfxOrganizeListBox_Impl::Reset()
-/* [Beschreibung]
-
- Einf"ugen der Elemente in die ListBox
+/* [Description]
+ Paste the items in the ListBox
*/
{
- DBG_ASSERT( pMgr != 0, "kein Manager" );
- // Inhalte l"oschen
+ DBG_ASSERT( pMgr != 0, "No Manager" );
+ // Delete contents
SetUpdateMode(FALSE);
Clear();
if ( VIEW_TEMPLATES == eViewType )
@@ -1414,19 +1403,17 @@ void SfxOrganizeListBox_Impl::Reset()
const Image &SfxOrganizeListBox_Impl::GetClosedBmp(USHORT nLevel) const
-/* [Beschreibung]
+/* [Description]
- Zugriff auf die Bitmap f"ur einen geschlossenen Eintrag
- der jeweiligen Ebene
+ Access to the bitmap for a closed entry at each level
[Parameter]
- USHORT nLevel Angabe der Ebene, 2 Ebenen sind erlaubt
-
- [Returnwert]
+ USHORT nLevel Indicator of the level, 2 levels are allowed
- const Image & das Image auf der Ebenen nLevel
+ [Return value]
+ const Image & The Image on level nLevel
*/
{
@@ -1434,7 +1421,7 @@ const Image &SfxOrganizeListBox_Impl::GetClosedBmp(USHORT nLevel) const
switch( nLevel )
{
- default: OSL_FAIL( "Bitmaps ueberindiziert" );
+ default: OSL_FAIL( "Bitmap index overflow" );
case 0: pRet = &aClosedFolderBmp;
break;
@@ -1449,18 +1436,17 @@ const Image &SfxOrganizeListBox_Impl::GetClosedBmp(USHORT nLevel) const
const Image &SfxOrganizeListBox_Impl::GetOpenedBmp(USHORT nLevel) const
-/* [Beschreibung]
+/* [Description]
- Zugriff auf die Bitmap f"ur einen ge"offneten Eintrag
- der jeweiligen Ebene
+ Access to the bitmap for an open entry at each level
[Parameter]
- USHORT nLevel Angabe der Ebene, 2 Ebenen sind erlaubt
+ USHORT nLevel Indicator of the level, 2 levels are allowed
- [Returnwert]
+ [Return value]
- const Image & das Image auf der Ebenen nLevel
+ const Image & the image on the level nLevel
*/
@@ -1491,18 +1477,17 @@ PopupMenu* SfxOrganizeListBox_Impl::CreateContextMenu()
String SfxOrganizeDlg_Impl::GetPath_Impl( BOOL bOpen, const String& rFileName )
-/* [Beschreibung]
+/* [Description]
- Pfad per FileDialog erfragen, f"ur Import / Export von
- Dokumentvorlagen
+ Get path from FileDialog, for Import / Export of Templates
[Parameter]
- BOOL bOpen Flag: "Offnen / Speichern
- const String& rFileName aktueller Dateiname als Vorschlag
+ BOOL bOpen Flag: Open / Save
+ const String& rFileName Current file name as default
- [R"uckgabewert] Dateiname mit Pfad oder Leerstring, wenn
- der Benutzer 'Abbrechen' gedr"uckt hat
+ [Return value] File name with path or empty string if
+ users has pressed 'Cancel'
*/
{
@@ -1686,12 +1671,12 @@ BOOL SfxOrganizeDlg_Impl::DontDelete_Impl( SvLBoxEntry* pEntry )
pFocusBox->GetViewType())
nDepth++;
if( (nDepth > 2 && !pEntry->GetUserData()) ||
- //Delete ueber GetContent verboten
- nDepth==2 || //Vorlage / Konfigurtionsrubrik nicht loeshcen
+ //Delete using GetContent forbidden
+ nDepth==2 || // Template / Not deleting config header
(nDepth==1 && SfxOrganizeListBox_Impl::VIEW_FILES ==
- pFocusBox->GetViewType()) || //Files nicht loeschen
+ pFocusBox->GetViewType()) || //Not deleting Files
(0 == nDepth && pFocusBox->GetLevelCount_Impl(0) < 2))
- //Mindestens eine Vorlage behalten
+ //At least keep one template
{
return TRUE;
}
@@ -1758,17 +1743,16 @@ sal_Bool SfxOrganizeDlg_Impl::GetServiceName_Impl( String& rName, String& rFileU
long SfxOrganizeDlg_Impl::Dispatch_Impl( USHORT nId, Menu* _pMenu )
-/* [Beschreibung]
+/* [Description]
- Verarbeiten der Events aus MenuButton oder Accelerator
+ Processing the events from MenuButton or Accelerator
[Parameter]
- USHORT nId ID des Events
-
- [R"uckgabewert] 1: Event wurde verarbeitet,
- 0: Event wurde nicht verarbeitet (SV-Menu)
+ USHORT nId Event ID
+ [Return value] 1: Event has been processed,
+ 0: Event has not been processed (SV-Menu)
*/
{
@@ -1834,7 +1818,7 @@ long SfxOrganizeDlg_Impl::Dispatch_Impl( USHORT nId, Menu* _pMenu )
( nDeleteInd == USHRT_MAX && pFocusBox->GetChildCount(pEntry) ) );
}
}
- // Inhaltsformen
+ //Content Format
else if(nDepth + pFocusBox->GetDocLevel() >= 2)
{
if(!QueryDelete_Impl(pDialog, STR_DELETE_TEMPLATE, pFocusBox->GetEntryText(pEntry)))
@@ -1964,17 +1948,16 @@ long SfxOrganizeDlg_Impl::Dispatch_Impl( USHORT nId, Menu* _pMenu )
IMPL_LINK_INLINE_START( SfxOrganizeDlg_Impl, MenuSelect_Impl, Menu *, pMenu )
-/* [Beschreibung]
+/* [Description]
- SelectHandler des Men"us des Men"ubuttons (SV)
+ SelectHandler of Menu and Menubuttons (SV)
[Parameter]
- MenuButton *pBtn der das Event ausl"osende Button
-
- [R"uckgabewert] 1: Event wurde verarbeitet,
- 0: Event wurde nicht verarbeitet (SV-Menu)
+ MenuButton *pBtn Button triggering the event
+ [Return value] 1: Event has been processed,
+ 0: Event has not been processed (SV-Menu)
*/
{
return Dispatch_Impl( pMenu->GetCurItemId(), pMenu );
@@ -1985,17 +1968,16 @@ IMPL_LINK_INLINE_END( SfxOrganizeDlg_Impl, MenuSelect_Impl, Menu *, pMenu )
IMPL_LINK( SfxOrganizeDlg_Impl, AccelSelect_Impl, Accelerator *, pAccel )
-/* [Beschreibung]
+/* [Description]
- SelectHandler des Accelerators (SV)
+ SelectHandler of Accelerators (SV)
[Parameter]
- Accelerator *pAccel der das Event ausl"osende Accelerator
-
- [R"uckgabewert] 1: Event wurde verarbeitet,
- 0: Event wurde nicht verarbeitet (SV)
+ Accelerator *pAccel Accelerator triggering the event
+ [Return value] 1: Event has been processed,
+ 0: Event has not been processed (SV)
*/
{
@@ -2018,17 +2000,16 @@ void SfxOrganizeDlg_Impl::OkHdl(Button *pButton)
IMPL_LINK( SfxOrganizeDlg_Impl, MenuActivate_Impl, Menu *, pMenu )
-/* [Beschreibung]
+/* [Description]
- ActivateHandler des Men"us des Men"ubuttons (SV)
+ ActivateHandler of Menu and Menubuttons (SV)
[Parameter]
- Menu *pMenu das das Event ausl"osende Men"u
-
- [R"uckgabewert] 1: Event wurde verarbeitet,
- 0: Event wurde nicht verarbeitet (SV-Menu)
+ Menu *pMenu Event triggering the Menu
+ [Return value] 1: Event has been processed,
+ 0: Event has not been processed (SV-Menu)
*/
{
if ( pFocusBox && pFocusBox->IsEditingActive() )
@@ -2039,11 +2020,11 @@ IMPL_LINK( SfxOrganizeDlg_Impl, MenuActivate_Impl, Menu *, pMenu )
( bEnable && pFocusBox->GetSelectionCount() ) ? pFocusBox->GetModel()->GetDepth( pEntry ) : 0;
const USHORT nDocLevel = bEnable ? pFocusBox->GetDocLevel() : 0;
int eVT = pFocusBox ? pFocusBox->GetViewType() : 0;
- // nur Vorlagen anlegen
+ // Create only Template
pMenu->EnableItem( ID_NEW, bEnable && 0 == nDepth && SfxOrganizeListBox_Impl::VIEW_TEMPLATES == eVT );
- // Vorlagen: Loeschen Ebene 0,1,3ff
- // ein Bereich mu"s mindestens erhalten bleiben
- // Dateien : Loeschen Ebene > 2
+ // Template: Delete level 0,1,3ff
+ // At least one region must be retained
+ // Files: Delete level> 2
pMenu->EnableItem( ID_DELETE, bEnable && !DontDelete_Impl( pEntry ) );
pMenu->EnableItem( ID_EDIT,
@@ -2111,17 +2092,14 @@ IMPL_LINK( SfxOrganizeDlg_Impl, MenuActivate_Impl, Menu *, pMenu )
IMPL_LINK( SfxOrganizeDlg_Impl, GetFocus_Impl, SfxOrganizeListBox_Impl *, pBox )
-/* [Beschreibung]
+/* [Description]
- GetFocus-Handler, wird aus den Select-Handler der Listboxen
- gerufen.
- Wird verwendet, im die Listbox, die den Focus besitzt sowie
- deren Zustand zu ermitteln.
+ GetFocus-Handler, is called from the Select-Handler of ListBox
+ Used in the listBox that has the focus and to determine its condition.
[Parameter]
- SfxOrganizeListBox *pBox die rufende Box
-
+ SfxOrganizeListBox *pBox The calling Box
*/
{
@@ -2137,17 +2115,15 @@ IMPL_LINK( SfxOrganizeDlg_Impl, GetFocus_Impl, SfxOrganizeListBox_Impl *, pBox )
IMPL_LINK( SfxOrganizeDlg_Impl, LeftListBoxSelect_Impl, ListBox *, pBox )
-/* [Beschreibung]
+/* [Description]
- Select-Handler, wird aus den Select-Handler der Listboxen
- gerufen.
- Wenn sich der Modus der Boxen (Dokumentsicht, Dokumentvorlagensicht)
- unterscheiden, werden die Models getrennt; andernfalls zusammengefa"st.
+ Select-Handler, is called from the Select-Handler of ListBox.
+ If the mode of the Boxes are different (Document view or Template view)
+ then the models are separated, otherwise joined together.
[Parameter]
- ListBox *pBox die rufende Box
-
+ ListBox *pBox The calling Box
*/
{
const SfxOrganizeListBox_Impl::DataEnum
@@ -2171,17 +2147,15 @@ IMPL_LINK( SfxOrganizeDlg_Impl, LeftListBoxSelect_Impl, ListBox *, pBox )
IMPL_LINK( SfxOrganizeDlg_Impl, RightListBoxSelect_Impl, ListBox *, pBox )
-/* [Beschreibung]
+/* [Description]
- Select-Handler, wird aus den Select-Handler der Listboxen
- gerufen.
- Wenn sich der Modus der Boxen (Dokumentsicht, Dokumentvorlagensicht)
- unterscheiden, werden die Models getrennt; andernfalls zusammengefa"st.
+ Select-Handler, will be called by Select-Handler of the ListBox.
+ If the mode of the Boxes are different (Document view or Template view)
+ then the models are separated, otherwise joined together.
[Parameter]
- ListBox *pBox die rufende Box
-
+ ListBox *pBox The calling Box
*/
{
const SfxOrganizeListBox_Impl::DataEnum eViewType =
@@ -2194,7 +2168,7 @@ IMPL_LINK( SfxOrganizeDlg_Impl, RightListBoxSelect_Impl, ListBox *, pBox )
aRightLb.SetModel(aLeftLb.GetModel());
else
{
- // Models trennen
+ // Separate models
aRightLb.DisconnectFromModel();
aRightLb.Reset();
}
@@ -2218,13 +2192,13 @@ IMPL_LINK( SfxOrganizeDlg_Impl, OnAddressTemplateClicked, Button *, pButton )
IMPL_LINK( SfxOrganizeDlg_Impl, AddFiles_Impl, Button *, pButton )
-/* [Beschreibung]
+/* [Description]
- Handler des Buttons f"ur das Hinzuf"ugen von Dateien per Dialog.
+ Handler of the button for adding files through Dialog.
[Parameter]
- Button * der Button, der dieses Events ausgel"ost hat.
+ Button * Button, triggering this Event
*/
{
@@ -2371,10 +2345,9 @@ IMPL_LINK( SfxOrganizeDlg_Impl, AddFilesHdl, sfx2::FileDialogHelper *, EMPTYARG
short SfxTemplateOrganizeDlg::Execute()
-/* [Beschreibung]
+/* [Description]
- "Uberladene Execute- Methode; speichert gfs. "Anderungen an den
- Dokumentvorlagen
+ Overloaded Execute method; stores changes to the document templates
(SV-Methode)
*/
@@ -2399,10 +2372,9 @@ SfxTemplateOrganizeDlg::SfxTemplateOrganizeDlg(Window * pParent,
: ModalDialog( pParent, SfxResId(DLG_ORGANIZE)),
pImp( new SfxOrganizeDlg_Impl(this, pTempl) )
-/* [Beschreibung]
-
- Konstruktor
+/* [Description]
+ Constructor
*/
{
FreeResource();
diff --git a/sfx2/source/doc/frmdescr.cxx b/sfx2/source/doc/frmdescr.cxx
index 6718860..905b26b 100644
--- a/sfx2/source/doc/frmdescr.cxx
+++ b/sfx2/source/doc/frmdescr.cxx
@@ -162,7 +162,7 @@ SfxFrameDescriptor* SfxFrameDescriptor::Clone( BOOL bWithIds ) const
pFrame->pImp->pWallpaper = new Wallpaper( *pImp->pWallpaper );
if( pImp->pArgs )
{
- // Aktuell ist im Clone von SfxAllItemSets noch ein Bug...
+ // Currently in the clone of SfxAllItemSets there is still a bug ...
pFrame->pImp->pArgs = new SfxAllItemSet( SFX_APP()->GetPool() );
pFrame->pImp->pArgs->Put(*pImp->pArgs);
}
diff --git a/sfx2/source/doc/new.cxx b/sfx2/source/doc/new.cxx
index f8abaa1..939ad1a 100644
--- a/sfx2/source/doc/new.cxx
+++ b/sfx2/source/doc/new.cxx
@@ -276,8 +276,8 @@ public:
SfxNewFileDialog_Impl( SfxNewFileDialog* pAntiImplP, USHORT nFlags );
~SfxNewFileDialog_Impl();
- // Liefert FALSE, wenn '- Keine -' als Vorlage eingestellt ist
- // Nur wenn IsTemplate() TRUE liefert, koennen Vorlagennamen
+ // Returns FALSE if '- No -' is set as a template
+ // Template name can only be obtained if IsTemplate() is TRUE
// erfragt werden
BOOL IsTemplate() const;
String GetTemplateRegion() const;
@@ -436,12 +436,12 @@ IMPL_LINK( SfxNewFileDialog_Impl, PreviewClick, CheckBox *, pBox )
IMPL_LINK( SfxNewFileDialog_Impl, TemplateSelect, ListBox *, EMPTYARG )
{
- // noch am Laden
+ // Still loading
if ( xDocShell && xDocShell->GetProgress() )
return 0;
if ( !MORE_BTN(GetState()) )
- // Dialog nicht aufgeklappt
+ // Dialog is not opened
return 0;
aPrevTimer.Start();
@@ -453,7 +453,7 @@ IMPL_LINK( SfxNewFileDialog_Impl, TemplateSelect, ListBox *, EMPTYARG )
IMPL_LINK_INLINE_START( SfxNewFileDialog_Impl, DoubleClick, ListBox *, pListBox )
{
(void)pListBox;
- // noch am Laden
+ // Still loadning
if ( !xDocShell.Is() || !xDocShell->GetProgress() )
pAntiImpl->EndDialog(RET_OK);
return 0;
diff --git a/sfx2/source/doc/objcont.cxx b/sfx2/source/doc/objcont.cxx
index d0f4490..ecccdd4 100644
--- a/sfx2/source/doc/objcont.cxx
+++ b/sfx2/source/doc/objcont.cxx
@@ -126,8 +126,8 @@ SfxObjectShell::GetPreviewMetaFile( sal_Bool bFullContent ) const
::boost::shared_ptr<GDIMetaFile>
SfxObjectShell::CreatePreviewMetaFile_Impl( sal_Bool bFullContent ) const
{
- // Nur wenn gerade nicht gedruckt wird, darf DoDraw aufgerufen
- // werden, sonst wird u.U. der Printer abgeschossen !
+ // DoDraw can only be called when no printing is done, otherwise
+ // the printer may be turned off
SfxViewFrame *pFrame = SfxViewFrame::GetFirst( this );
if ( pFrame && pFrame->GetViewShell() &&
pFrame->GetViewShell()->GetPrinter() &&
@@ -233,7 +233,7 @@ lcl_add(util::Duration & rDur, Time const& rTime)
rDur.Seconds += rTime.GetSec();
}
-// Bearbeitungszeit aktualisieren
+// Update the processing time
void SfxObjectShell::UpdateTime_Impl(
const uno::Reference<document::XDocumentProperties> & i_xDocProps)
{
@@ -484,8 +484,8 @@ BOOL SfxObjectShell::Insert(SfxObjectShell &rSource,
if ( pHisPool && pHisPool->Count() > nSourceIdx2 )
pHisSheet = (*pHisPool)[nSourceIdx2];
- // Einfuegen ist nur dann noetig, wenn ein StyleSheet
- // zwischen unterschiedlichen(!) Pools bewegt wird
+ // Pasting is only needed if a style sheet is moved between
+ // different (!) Pools
if ( pHisSheet && pMyPool != pHisPool )
{
@@ -494,12 +494,12 @@ BOOL SfxObjectShell::Insert(SfxObjectShell &rSource,
nIdx2 = pMyPool->Count();
}
- // wenn so eine Vorlage schon existiert: loeschen!
+ // if such a template already exists: delete!
String aOldName(pHisSheet->GetName());
SfxStyleFamily eOldFamily = pHisSheet->GetFamily();
SfxStyleSheetBase* pExist = pMyPool->Find(aOldName, eOldFamily);
- // USHORT nOldHelpId = pExist->GetHelpId(??? VB ueberlegt sich was);
+ // USHORT nOldHelpId = pExist->GetHelpId(???);
BOOL bUsedOrUserDefined;
if( pExist )
{
@@ -522,10 +522,11 @@ BOOL SfxObjectShell::Insert(SfxObjectShell &rSource,
aOldName, eOldFamily,
pHisSheet->GetMask(), nIdx2);
- // ItemSet der neuen Vorlage fuellen
+ // Fill the Itemset of the new template
rNewSheet.GetItemSet().Set(pHisSheet->GetItemSet());
- // wer bekommt den Neuen als Parent? wer benutzt den Neuen als Follow?
+ // Who gets the new one as a Parent?
+ // Who is using the new one as Follow?
SfxStyleSheetBase* pTestSheet = pMyPool->First();
while (pTestSheet)
{
@@ -534,7 +535,7 @@ BOOL SfxObjectShell::Insert(SfxObjectShell &rSource,
pTestSheet->GetParent() == aOldName)
{
pTestSheet->SetParent(aOldName);
- // Verknuepfung neu aufbauen
+ // Rebuild Link
}
if (pTestSheet->GetFamily() == eOldFamily &&
@@ -542,7 +543,7 @@ BOOL SfxObjectShell::Insert(SfxObjectShell &rSource,
pTestSheet->GetFollow() == aOldName)
{
pTestSheet->SetFollow(aOldName);
- // Verknuepfung neu aufbauen
+ // Rebuild Link
}
pTestSheet = pMyPool->Next();
@@ -551,7 +552,7 @@ BOOL SfxObjectShell::Insert(SfxObjectShell &rSource,
rNewSheet.IsUsed() || rNewSheet.IsUserDefined();
- // hat der Neue einen Parent? wenn ja, mit gleichem Namen bei uns suchen
+ // has a New Parent? if so, start search with the same name
if (pHisSheet->HasParentSupport())
{
const String& rParentName = pHisSheet->GetParent();
@@ -564,8 +565,8 @@ BOOL SfxObjectShell::Insert(SfxObjectShell &rSource,
}
}
- // hat der Neue einen Follow? wenn ja, mit gleichem
- // Namen bei uns suchen
+ // Has the new got a Follow? if so start search
+ // with the same name.
if (pHisSheet->HasFollowSupport())
{
const String& rFollowName = pHisSheet->GetFollow();
@@ -621,14 +622,14 @@ BOOL SfxObjectShell::Remove
pTestSheet->HasParentSupport() &&
pTestSheet->GetParent() == aName)
{
- pTestSheet->SetParent(aEmpty); // Verknuepfung aufloesen
+ pTestSheet->SetParent(aEmpty); // Remove link
}
if (pTestSheet->GetFamily() == eFamily &&
pTestSheet->HasFollowSupport() &&
pTestSheet->GetFollow() == aName)
{
- pTestSheet->SetFollow(aEmpty); // Verknuepfung aufloesen
+ pTestSheet->SetFollow(aEmpty); // Remove link
}
pTestSheet = pMyPool->Next();
@@ -663,7 +664,7 @@ BOOL SfxObjectShell::Print
if ( !pStyle )
return TRUE;
- // pepare adaptor for old style StartPage/EndPage printing
+ // prepare adaptor for old style StartPage/EndPage printing
boost::shared_ptr< Printer > pPrinter( new Printer( rPrt.GetJobSetup() ) );
vcl::OldStylePrintAdaptor* pAdaptor = new vcl::OldStylePrintAdaptor( pPrinter );
boost::shared_ptr< vcl::PrinterController > pController( pAdaptor );
@@ -778,18 +779,17 @@ BOOL SfxObjectShell::Print
void SfxObjectShell::LoadStyles
(
- SfxObjectShell &rSource /* die Dokument-Vorlage, aus der
- die Styles geladen werden sollen */
+ SfxObjectShell &rSource /* the document template from which
+ the styles are to be loaded * /
)
-/* [Beschreibung]
+/* [Description]
- Diese Methode wird vom SFx gerufen, wenn aus einer Dokument-Vorlage
- Styles nachgeladen werden sollen. Bestehende Styles soll dabei
- "uberschrieben werden. Das Dokument mu"s daher neu formatiert werden.
- Daher werden die Applikationen in der Regel diese Methode "uberladen
- und in ihrer Implementierung die Implementierung der Basisklasse
- rufen.
+ This method is called by the SFx if template styles are to be loaded.
+ Existing styles are in this case overwritten. The document has then to be
+ newly formatted. Therefore, the application of this method is usually
+ overloaded and its implementation is calling the implementation in
+ the base class.
*/
{
@@ -816,7 +816,7 @@ void SfxObjectShell::LoadStyles
{
pDest = &pMyPool->Make( pSource->GetName(),
pSource->GetFamily(), pSource->GetMask());
- // Setzen des Parents, der Folgevorlage
+ // Setting of Parents, the next style
}
pFound[nFound].pSource = pSource;
pFound[nFound].pDest = pDest;
@@ -839,13 +839,12 @@ void SfxObjectShell::LoadStyles
void SfxObjectShell::UpdateFromTemplate_Impl( )
-/* [Beschreibung]
+/* [Description]
- Diese interne Methode pr"uft, ob das Dokument aus einem Template
- erzeugt wurde, und ob dieses neuer ist als das Dokument. Ist dies
- der Fall, wird der Benutzer gefragt, ob die Vorlagen (StyleSheets)
- updated werden sollen. Wird dies positiv beantwortet, werden die
- StyleSheets updated.
+ This internal method checks whether the document was created from a
+ template, and if this is newer than the document. If this is the case,
+ the user is asked if the Templates (StyleSheets) should be updated.
+ If this is answered positively, the StyleSheets are updated.
*/
{
@@ -875,10 +874,10 @@ void SfxObjectShell::UpdateFromTemplate_Impl( )
if ( aTemplName.getLength() || (aTemplURL.getLength() && !IsReadOnly()) )
{
- // try to locate template, first using filename
- // this must be done because writer global document uses this "great" idea to manage the templates of all parts
- // in the master document
- // but it is NOT an error if the template filename points not to a valid file
+ // try to locate template, first using filename this must be done
+ // because writer global document uses this "great" idea to manage
+ // the templates of all parts in the master document but it is NOT
+ // an error if the template filename points not to a valid file
SfxDocumentTemplates aTempl;
aTempl.Construct();
if ( aTemplURL.getLength() )
@@ -889,7 +888,8 @@ void SfxObjectShell::UpdateFromTemplate_Impl( )
}
if( !aFoundName.Len() && aTemplName.getLength() )
- // if the template filename did not lead to success, try to get a file name for the logical template name
+ // if the template filename did not lead to success,
+ // try to get a file name for the logical template name
aTempl.GetFull( String(), aTemplName, aFoundName );
}
diff --git a/sfx2/source/doc/objembed.cxx b/sfx2/source/doc/objembed.cxx
index 6ca5bcc..21d5edf 100644
--- a/sfx2/source/doc/objembed.cxx
+++ b/sfx2/source/doc/objembed.cxx
@@ -212,15 +212,15 @@ void SfxObjectShell::DoDraw_Impl( OutputDevice* pDev,
aMapMode.SetScaleX( rScaleX );
aMapMode.SetScaleY( rScaleY );
- // Ziel in Pixel
+ // Target in Pixels
Point aOrg = pDev->LogicToLogic( rViewPos, NULL, &aMapMode );
Point aDelta = aOrg - aVisArea.TopLeft();
- // Origin entsprechend zum sichtbaren Bereich verschieben
- // Origin mit Scale setzen
+ // Origin moved according to the viewable area
+ // Origin set with Scale
aMapMode.SetOrigin( aDelta );
- // Deviceeinstellungen sichern
+ // Secure the Device settings
pDev->Push();
Region aRegion;
@@ -249,7 +249,7 @@ void SfxObjectShell::DoDraw_Impl( OutputDevice* pDev,
Draw( pDev, rSetup, nAspect );
- // Deviceeinstellungen wieder herstellen
+ // Restore Device settings
pDev->Pop();
}
diff --git a/sfx2/source/doc/objmisc.cxx b/sfx2/source/doc/objmisc.cxx
index 584be67..61d6c28 100644
--- a/sfx2/source/doc/objmisc.cxx
+++ b/sfx2/source/doc/objmisc.cxx
@@ -295,7 +295,7 @@ void SfxObjectShell::EnableSetModified( sal_Bool bEnable )
{
#ifdef DBG_UTIL
if ( bEnable == pImp->m_bEnableSetModified )
- DBG_WARNING( "SFX_PERSIST: EnableSetModified 2x mit dem gleichen Wert gerufen" );
+ DBG_WARNING( "SFX_PERSIST: EnableSetModified 2x called with the same value" );
#endif
pImp->m_bEnableSetModified = bEnable;
}
@@ -353,7 +353,7 @@ void SfxObjectShell::SetModified( sal_Bool bModifiedP )
{
#ifdef DBG_UTIL
if ( !bModifiedP && !IsEnableSetModified() )
- DBG_WARNING( "SFX_PERSIST: SetModified( sal_False ), obwohl IsEnableSetModified() == sal_False" );
+ DBG_WARNING( "SFX_PERSIST: SetModified( sal_False ), although IsEnableSetModified() == sal_False" );
#endif
if( !IsEnableSetModified() )
@@ -371,7 +371,7 @@ void SfxObjectShell::SetModified( sal_Bool bModifiedP )
void SfxObjectShell::ModifyChanged()
{
if ( pImp->bClosing )
- // SetModified aus dem dispose des Models!
+ // SetModified dispose of the models!
return;
{DBG_CHKTHIS(SfxObjectShell, 0);}
@@ -391,11 +391,10 @@ void SfxObjectShell::ModifyChanged()
sal_Bool SfxObjectShell::IsReadOnlyUI() const
-/* [Beschreibung]
+/* [Description]
- Liefert sal_True, wenn das Dokument fuer die UI wie r/o behandelt werden
- soll. Dieses ist unabhaengig vom tatsaechlichen r/o, welches per
- <IsReadOnly()> erfragbar ist.
+ Returns sal_True if the document for the UI is treated as r/o. This is
+ regardless of the actual r/o, which can be checked with <IsReadOnly()>.
*/
{
@@ -406,9 +405,9 @@ sal_Bool SfxObjectShell::IsReadOnlyUI() const
sal_Bool SfxObjectShell::IsReadOnlyMedium() const
-/* [Beschreibung]
+/* [Description]
- Liefert sal_True, wenn das Medium r/o ist bzw. r/o geoeffnet wurde.
+ Returns sal_True when the medium is r/o, for instance when opened as r/o.
*/
{
@@ -421,10 +420,10 @@ sal_Bool SfxObjectShell::IsReadOnlyMedium() const
void SfxObjectShell::SetReadOnlyUI( sal_Bool bReadOnly )
-/* [Beschreibung]
+/* [Description]
- Schaltet das Dokument in einen r/o bzw. r/w Zustand ohne es neu
- zu laden und ohne die Open-Modi des Mediums zu aendern.
+ Turns the document in an r/o and r/w state respectively without reloading
+ it and without changing the open mode of the medium.
*/
{
@@ -512,17 +511,18 @@ void SfxObjectShell::SetMacroMode_Impl( sal_Bool bModal )
void SfxObjectShell::SetModalMode_Impl( sal_Bool bModal )
{
- // nur Broadcasten wenn modifiziert, sonst ggf. Endlosrekursion
+ // Broadcast only if modified, or otherwise it will possibly go into
+ // an endless loop
if ( !pImp->bModalMode != !bModal )
{
- // zentral mitz"ahlen
+ // Central count
sal_uInt16 &rDocModalCount = SFX_APP()->Get_Impl()->nDocModalMode;
if ( bModal )
++rDocModalCount;
else
--rDocModalCount;
- // umschalten
+ // Switch
pImp->bModalMode = bModal;
Broadcast( SfxSimpleHint( SFX_HINT_MODECHANGED ) );
}
@@ -774,38 +774,39 @@ IndexBitSet& SfxObjectShell::GetNoSet_Impl()
void SfxObjectShell::SetTitle
(
- const String& rTitle // der neue Titel des Dokuments
+ const String& rTitle // the new Document Title
)
-/* [Beschreibung]
+/* [Description]
- Mit dieser Methode kann der Titel des Dokuments gesetzt werden.
- Dieser entspricht initial dem kompletten Dateinamen. Ein Setzen
- des Titels wirkt jedoch nicht zu"uck auf den Dateinamen; er wird
- jedoch in den Caption-Bars der MDI-Fenster angezeigt.
+ With this method, the title of the document can be set.
+ This corresponds initially to the full file name. A setting of the
+ title does not affect the file name, but it will be shown in the
+ Caption-Bars of the MDI-window.
*/
{
DBG_CHKTHIS(SfxObjectShell, 0);
- // nix zu tun?
+ // Nothing to do?
if ( ( ( HasName() && pImp->aTitle == rTitle )
|| ( !HasName() && GetTitle() == rTitle ) )
&& !IsDocShared() )
return;
SfxApplication *pSfxApp = SFX_APP();
- // ggf. die unbenannt-Nummer freigeben
+
+ // If possible relase the unnamed number.
if ( pImp->bIsNamedVisible && USHRT_MAX != pImp->nVisualDocumentNumber )
{
pSfxApp->ReleaseIndex(pImp->nVisualDocumentNumber);
pImp->bIsNamedVisible = 0;
}
- // Title setzen
+ // Set Title
pImp->aTitle = rTitle;
- // Benachrichtigungen
+ // Notification
if ( GetMedium() )
{
SfxShell::SetName( GetTitle(SFX_TITLE_APINAME) );
@@ -831,52 +832,53 @@ String X(const String &rRet)
String SfxObjectShell::GetTitle
(
sal_uInt16 nMaxLength /* 0 (default)
- der Titel selbst, so wie er ist
+ the title itself, as it is
1 (==SFX_TITLE_FILENAME)
- liefert den logischen Dateinamen ohne Pfad
- (unter WNT je nach Systemeinstellung ohne
- Extension)
+ provides the logical file name without path
+ (under WNT depending on the system settings
+ without extension)
2 (==SFX_TITLE_FULLNAME)
- liefert den mit komplettem logischen Dateinamen
- mit Pfad (remote => ::com::sun::star::util::URL)
+ provides the logical file names with full path
+ (remote =>:: com:: sun:: star:: util:: URL)
3 (==SFX_TITLE_APINAME)
- liefert den logischen Dateinamen ohne Pfad
- und Extension
+ provides the logical filname without path
+ and extension
4 (==SFX_TITLE_DETECT)
- liefert den kompletten Titel, falls noch
- nicht gesetzt wird aber aus DocInfo oder
- dem Namen des Medium erzeugt
+ provides the complete title, if not set yet
+ it will be created from DocInfo or the name of
+ the medium.
5 (==SFX_TITLE_CAPTION)
- liefert den Titel so, wie MB ihn heute in
- der CaptionBar anzeigen m"ochte
+ provides the Title just like MB now in the
+ CaptionBar view
6 (==SFX_TITLE_PICKLIST)
- liefert den Titel so, wie MB ihn heute in
- der PickList anzeigen m"ochte
+ returns the Title, just like MB now would
+ display it in the in the PickList
7 (==SFX_TITLE_HISTORY)
- liefert den Titel so, wie MB ihn heute in
- der History anzeigen m"ochte
+ returns the Title just like MB now would
+ display it in the in the History
10 bis USHRT_MAX
- liefert maximal 'nMaxLength' Zeichen vom logischen
- Dateinamen inkl. Pfad (remote => ::com::sun::star::util::URL)
+ provides the 'nMaxLength' of the logical
+ file name including the path
+ (remote => ::com::sun::star::util::URL)
*/
) const
-/* [Beschreibung]
+/* [Description]
- Liefert den Titel bzw. logischen Dateinamen des Dokuments, je nach
+ Returns the title or logical file name of the document, depending on the
'nMaxLength'.
- Falls der Dateiname mit Pfad verwendet wird, wird die Namensk"urzung durch
- Ersetzung eines oder mehrerer Directory-Namen durch "..." durchgef"uhrt,
- URLs werden z.Zt. immer komplett geliefert.
+ If the file name with path is used, the Name shortened by replacing one or
+ more directory names with "...", URLs are currently always returned
+ in complete form.
*/
{
@@ -884,7 +886,7 @@ String SfxObjectShell::GetTitle
if ( IsLoading() )
return String();
- // Titel erzeugen?
+ // Create Title?
if ( SFX_TITLE_DETECT == nMaxLength && !pImp->aTitle.Len() )
{
static sal_Bool bRecur = sal_False;
@@ -913,38 +915,37 @@ String SfxObjectShell::GetTitle
else if (SFX_TITLE_APINAME == nMaxLength )
return X(GetAPIName());
- // Sonderfall Vorlagen:
+ // Special case templates:
if( IsTemplate() && pImp->aTitle.Len() &&
( nMaxLength == SFX_TITLE_CAPTION || nMaxLength == SFX_TITLE_PICKLIST ) )
return X(pImp->aTitle);
- // Picklist/Caption wird gemappt
+ // Picklist/Caption is mapped
if ( pMed && ( nMaxLength == SFX_TITLE_CAPTION || nMaxLength == SFX_TITLE_PICKLIST ) )
{
- // Wenn ein spezieller Titel beim "Offnen mitgegeben wurde;
- // wichtig bei URLs, die INET_PROT_FILE verwenden, denn bei denen
- // wird der gesetzte Titel nicht beachtet.
- // (s.u., Auswertung von aTitleMap_Impl)
+ // If a specific title was given at open:
+ // important for URLs: use INET_PROT_FILE for which the set title is not
+ // considered. (See below, analysis of aTitleMap_Impl)
SFX_ITEMSET_ARG( pMed->GetItemSet(), pNameItem, SfxStringItem, SID_DOCINFO_TITLE, sal_False );
if ( pNameItem )
return X( pNameItem->GetValue() );
}
- // noch unbenannt?
- DBG_ASSERT( !HasName() || pMed, "HasName() aber kein Medium?!?" );
+ // Still unnamed?
+ DBG_ASSERT( !HasName() || pMed, "HasName() but no Medium?!?" );
if ( !HasName() || !pMed )
{
- // schon Titel gesezt?
+ // Title already set?
if ( pImp->aTitle.Len() )
return X(pImp->aTitle);
- // mu\s es durchnumeriert werden?
+ // must it be numbered?
String aNoName( SfxResId( STR_NONAME ) );
if ( pImp->bIsNamedVisible )
- // Nummer hintenanh"angen
+ // Append number
aNoName += String::CreateFromInt32( pImp->nVisualDocumentNumber );
- // Dokument hei\st vorerst 'unbenannt#'
+ // Document called "noname" for the time being
return X(aNoName);
}
@@ -959,7 +960,7 @@ String SfxObjectShell::GetTitle
nMaxLength = aTitleMap_Impl[nMaxLength-SFX_TITLE_CAPTION][nRemote];
}
- // lokale Datei?
+ // Local file?
if ( aURL.GetProtocol() == INET_PROT_FILE )
{
String aName( aURL.HasMark() ? INetURLObject( aURL.GetURLNoMark() ).PathToFileName() : aURL.PathToFileName() );
@@ -974,7 +975,7 @@ String SfxObjectShell::GetTitle
}
else
{
- // ::com::sun::star::util::URL-Versionen
+ // ::com::sun::star::util::URL-Versions
if ( nMaxLength >= SFX_TITLE_MAXLEN )
{
String aComplete( aURL.GetMainURL( INetURLObject::NO_DECODE ) );
@@ -998,7 +999,7 @@ String SfxObjectShell::GetTitle
else if ( nMaxLength == SFX_TITLE_FULLNAME )
return X(aURL.GetMainURL( INetURLObject::DECODE_TO_IURI ));
- // ggf. Titel aus Dateiname generieren
+ // Generate Title from file name if possible
if ( !pImp->aTitle.Len() )
pImp->aTitle = aURL.GetBase();
@@ -1007,7 +1008,7 @@ String SfxObjectShell::GetTitle
pImp->aTitle = aURL.GetMainURL( INetURLObject::DECODE_WITH_CHARSET );
}
- // ganzer Titel
+ // Complete Title
return X(pImp->aTitle);
}
@@ -1015,18 +1016,16 @@ String SfxObjectShell::GetTitle
void SfxObjectShell::InvalidateName()
-/* [Beschreibung]
+/* [Description]
- Ermittelt den Titel des Dokuments neu aus 'unbenannt', DocInfo-Titel
- bzw. Dateinamen. Wird nach Laden aus Template oder SaveAs ben"otigt.
+ Returns the title of the new document, DocInfo-Title or
+ File name. Is required for loading from template or SaveAs.
*/
{
- // Title neu erzeugen
pImp->aTitle.Erase();
SetName( GetTitle( SFX_TITLE_APINAME ) );
- // Benachrichtigungen
Broadcast( SfxSimpleHint(SFX_HINT_TITLECHANGED) );
}
@@ -1036,9 +1035,7 @@ void SfxObjectShell::SetNamedVisibility_Impl()
{
if ( !pImp->bIsNamedVisible )
{
- // Nummer verpassen
pImp->bIsNamedVisible = sal_True;
- // ggf. neue Nummer verpassen
if ( !HasName() && USHRT_MAX == pImp->nVisualDocumentNumber && !pImp->aTitle.Len() )
{
pImp->nVisualDocumentNumber = SFX_APP()->GetFreeIndex();
@@ -1073,14 +1070,14 @@ SfxProgress* SfxObjectShell::GetProgress() const
void SfxObjectShell::SetProgress_Impl
(
- SfxProgress *pProgress /* zu startender <SfxProgress> oder 0, falls
- der Progress zur"uckgesetzt werden soll */
+ SfxProgress *pProgress /* to started <SfxProgress> or 0,
+ if the progress is to be reset */
)
-/* [Beschreibung]
+/* [Description]
- Interne Methode zum setzen oder zur"ucksetzen des Progress-Modes
- f"ur diese SfxObjectShell.
+ Internal method to set or reset the Progress modes for
+ SfxObjectShell.
*/
{
@@ -1121,10 +1118,11 @@ void SfxObjectShell::SetActivateEvent_Impl(sal_uInt16 nId )
//--------------------------------------------------------------------
void SfxObjectShell::RegisterTransfer( SfxMedium& rMedium )
-/* [Beschreibung ]
- Alle Medien, die aufgesetzt werden, um Teile eines Dokumentes zu
- laden, muessen an der zugehoerigen SfxObjectShell angemeldet
- werden. So kann dokumentweise abgebrochen werden. */
+/* [Description]
+
+ All media, which are placed in order to load parts of a document must be
+ registered by a related SfxObjectShell. Thus documents can be canceled.
+*/
{
rMedium.SetReferer( GetMedium()->GetName() );
}
@@ -1132,9 +1130,10 @@ void SfxObjectShell::RegisterTransfer( SfxMedium& rMedium )
//-------------------------------------------------------------------------
void SfxObjectShell::PrepareReload( )
-/* [Beschreibung ]
- Wird vor dem Reload gerufen und gibt die Moeglichkeit,
- etwaige Caches zu leeren. */
+/* [Description]
+
+ Is called before the Reload and gives the opportunity to clear any caches.
+*/
{
}
@@ -1142,8 +1141,10 @@ void SfxObjectShell::PrepareReload( )
void SfxObjectShell::LockAutoLoad( sal_Bool bLock )
-/* Verhindert ein evtl. eintreffendes AutoLoad. Wird auch vor AutoLoad
- eines umgebenden FrameSet beruecksichtigt.
+/* [Description]
+
+ Prevents an possible occuring autoload. Takes also FrameSet into account.
+ before the autoload.
*/
{
@@ -1155,21 +1156,21 @@ void SfxObjectShell::LockAutoLoad( sal_Bool bLock )
//-------------------------------------------------------------------------
-// kann nach frame.cxx gemoved werden, wenn 358+36x-Stand gemerged sind
+// Can be moved to frame.cxx, when 358+36x-State have been merged
sal_Bool SfxFrame::IsAutoLoadLocked_Impl() const
{
- // sein einges Doc gelockt?
+ // Its own Docucument is locked?
const SfxObjectShell* pObjSh = GetCurrentDocument();
if ( !pObjSh || !pObjSh->IsAutoLoadLocked() )
return sal_False;
- // seine Childs gelockt?
+ // Its Childs are locked?
for ( sal_uInt16 n = GetChildFrameCount(); n--; )
if ( !GetChildFrame(n)->IsAutoLoadLocked_Impl() )
return sal_False;
- // sonst ist AutoLoad erlaubt
+ // otherwise allow AutoLoad
return sal_True;
}
@@ -1177,8 +1178,8 @@ sal_Bool SfxFrame::IsAutoLoadLocked_Impl() const
sal_Bool SfxObjectShell::IsAutoLoadLocked() const
-/* Liefert, ob ein eintreffendes AutoLoad ausgefuehrt werden darf. Wird auch
- vor AutoLoad eines umgebenden FrameSet beruecksichtigt.
+/* Returns whether an Autoload is allowed to be executed. Before the
+ surrounding FrameSet of the AutoLoad is also taken into account as well.
*/
{
@@ -1428,7 +1429,7 @@ void SfxObjectShell::TemplateDisconnectionAfterLoad()
else
{
// !TODO/LATER: what's this?!
- // Interaktiv ( DClick, Contextmenu ) kommt kein Langname mit
+ // Interactiv ( DClick, Contextmenu ) no long name is included
aTemplateName = getDocProperties()->getTitle();
if ( !aTemplateName.Len() )
{
@@ -1518,8 +1519,10 @@ void SfxObjectShell::PositionView_Impl()
//-------------------------------------------------------------------------
sal_Bool SfxObjectShell::IsLoading() const
-/* [Beschreibung ]
- Has FinishedLoading been called? */
+/* [Description]
+
+ Has FinishedLoading been called?
+*/
{
return !( pImp->nLoadedFlags & SFX_LOADED_MAINDOCUMENT );
}
@@ -1527,9 +1530,11 @@ sal_Bool SfxObjectShell::IsLoading() const
//-------------------------------------------------------------------------
void SfxObjectShell::CancelTransfers()
-/* [Beschreibung ]
- Hier koennen Transfers gecanceled werden, die nicht mit
- RegisterTransfer registiert wurden */
+/* [Description]
+
+ Here can Transfers get canceled, which were not regestered
+ by RegisterTransfer.
+*/
{
if( ( pImp->nLoadedFlags & SFX_LOADED_ALL ) != SFX_LOADED_ALL )
{
@@ -1556,10 +1561,10 @@ void AutoReloadTimer_Impl::Timeout()
if ( pFrame )
{
- // momentan nicht m"oglich/sinnvoll?
+ // Not possible/meanigfull at the moment?
if ( !pObjSh->CanReload_Impl() || pObjSh->IsAutoLoadLocked() || Application::IsUICaptured() )
{
- // erneuten Versuch erlauben
+ // Allow a retry
Start();
return;
}
@@ -1944,7 +1949,7 @@ SvKeyValueIterator* SfxObjectShell::GetHeaderAttributes()
{
if( !pImp->xHeaderAttributes.Is() )
{
- DBG_ASSERT( pMedium, "Kein Medium" );
+ DBG_ASSERT( pMedium, "No Medium" );
pImp->xHeaderAttributes = new SfxHeaderAttributes_Impl( this );
}
return ( SvKeyValueIterator*) &pImp->xHeaderAttributes;
@@ -1972,7 +1977,7 @@ sal_Bool SfxObjectShell::IsPreview() const
SFX_ITEMSET_ARG( pMedium->GetItemSet(), pFlags, SfxStringItem, SID_OPTIONS, sal_False);
if ( pFlags )
{
- // Werte auf einzelne Items verteilen
+ // Distributed values among individual items
String aFileFlags = pFlags->GetValue();
aFileFlags.ToUpperAscii();
if ( STRING_NOTFOUND != aFileFlags.Search( 'B' ) )
@@ -1991,11 +1996,11 @@ sal_Bool SfxObjectShell::IsPreview() const
sal_Bool SfxObjectShell::IsSecure()
{
- // Wenn globale Warnung an ist, nach Secure-Referer-Liste gehen
+ // When global warning is on, go to Secure-Referer-Liste
String aReferer = GetMedium()->GetName();
if ( !aReferer.Len() )
{
- // bei neuen Dokumenten das Template als Referer nehmen
+ // for new documents use the template as reference
::rtl::OUString aTempl( getDocProperties()->getTemplateURL() );
if ( aTempl.getLength() )
aReferer = INetURLObject( aTempl ).GetMainURL( INetURLObject::NO_DECODE );
@@ -2123,7 +2128,7 @@ Window* SfxObjectShell::GetDialogParent( SfxMedium* pLoadingMedium )
String SfxObjectShell::UpdateTitle( SfxMedium* pMed, USHORT nDocViewNumber )
{
- // Titel des Fensters
+ // Title of the windows
String aTitle;
if ( pMed )
{
diff --git a/sfx2/source/doc/objserv.cxx b/sfx2/source/doc/objserv.cxx
index 1753045..b2ed934 100644
--- a/sfx2/source/doc/objserv.cxx
+++ b/sfx2/source/doc/objserv.cxx
@@ -453,7 +453,8 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
aSet.Put( SfxStringItem( SID_EXPLORER_PROPS_START, aTitle ) );
aSet.Put( SfxStringItem( SID_BASEURL, GetMedium()->GetBaseURL() ) );
- // creating dialog is done via virtual method; application will add its own statistics page
+ // creating dialog is done via virtual method; application will
+ // add its own statistics page
SfxDocumentInfoDialog *pDlg = CreateDocumentInfoDialog(0, aSet);
if ( RET_OK == pDlg->Execute() )
{
@@ -497,7 +498,7 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
return;
}
... etc. - the rest is truncated
More information about the Libreoffice-commits
mailing list
diff --git a/sfx2/source/doc/docfile.cxx b/sfx2/source/doc/docfile.cxx
index 7a5ea62..e064221 100644
--- a/sfx2/source/doc/docfile.cxx
+++ b/sfx2/source/doc/docfile.cxx
@@ -1350,13 +1350,13 @@ uno::Reference < embed::XStorage > SfxMedium::GetStorage( sal_Bool bCreateTempIf
BOOL bResetStorage = FALSE;
if ( pVersion && pVersion->GetValue() )
{
- // Alle verf"ugbaren Versionen einlesen
+ // Read all available versions
if ( pImp->aVersions.getLength() )
{
- // Die zum Kommentar passende Version suchen
- // Die Versionen sind von 1 an durchnumeriert, mit negativen
- // Versionsnummern werden die Versionen von der aktuellen aus
- // r"uckw"arts gez"ahlt
+ // Search for the version fits the comment
+ // The versions are numbered startign with 1, versions with
+ // negative versions numbers are counted backwards from the
+ // current version
short nVersion = pVersion ? pVersion->GetValue() : 0;
if ( nVersion<0 )
nVersion = ( (short) pImp->aVersions.getLength() ) + nVersion;
@@ -1365,18 +1365,18 @@ uno::Reference < embed::XStorage > SfxMedium::GetStorage( sal_Bool bCreateTempIf
util::RevisionTag& rTag = pImp->aVersions[nVersion];
{
// SubStorage f"ur alle Versionen "offnen
uno::Reference < embed::XStorage > xSub = pImp->xStorage->openStorageElement( DEFINE_CONST_UNICODE( "Versions" ),
embed::ElementModes::READ );
- DBG_ASSERT( xSub.is(), "Versionsliste, aber keine Versionen!" );
+ DBG_ASSERT( xSub.is(), "Version list, but no Versions!" );
- // Dort ist die Version als gepackter Stream gespeichert
+ // There the version is stored as packed Stream
uno::Reference < io::XStream > xStr = xSub->openStreamElement( rTag.Identifier, embed::ElementModes::READ );
SvStream* pStream = utl::UcbStreamHelper::CreateStream( xStr );
if ( pStream && pStream->GetError() == SVSTREAM_OK )
{
- // Stream ins TempDir auspacken
+ // Unpack Stream in TempDir
::utl::TempFile aTempFile;
String aTmpName = aTempFile.GetURL();
SvFileStream aTmpStream( aTmpName, SFX_STREAM_READWRITE );
@@ -1384,7 +1384,7 @@ uno::Reference < embed::XStorage > SfxMedium::GetStorage( sal_Bool bCreateTempIf
*pStream >> aTmpStream;
aTmpStream.Close();
- // Datei als Storage "offnen
+ // Open data as Storage
nStorOpenMode = SFX_STREAM_READONLY;
pImp->xStorage = comphelper::OStorageHelper::GetStorageFromURL( aTmpName, embed::ElementModes::READ );
pImp->bStorageBasedOnInStream = sal_False;
@@ -2409,10 +2409,10 @@ void SfxMedium::DownLoad( const Link& aLink )
//------------------------------------------------------------------
void SfxMedium::Init_Impl()
-/* [Beschreibung]
- Setzt in den Logischen Namen eine gueltige ::com::sun::star::util::URL (Falls zuvor ein Filename
- drin war) und setzt den physikalschen Namen auf den Filenamen, falls
- vorhanden.
+/* [Description]
+ Includes a valid:: sun:: com:: star:: util:: URL (If a file name was
+ previously in there) in the logical name and if available sets the
+ physical name as the file name.
*/
{
@@ -2510,7 +2510,7 @@ SfxMedium::SfxMedium( const SfxMedium& rMedium, sal_Bool bTemporary )
aName = rMedium.aName;
pImp->bIsTemp = bTemporary;
- DBG_ASSERT( ! rMedium.pImp->bIsTemp, "Temporaeres Medium darf nicht kopiert werden" );
+ DBG_ASSERT( ! rMedium.pImp->bIsTemp, "Temporary Medium may not be copied" );
aLogicName = rMedium.aLogicName;
pSet = rMedium.GetItemSet() ? new SfxItemSet(*rMedium.GetItemSet()) : 0;
pFilter = rMedium.pFilter;
@@ -2768,8 +2768,8 @@ void SfxMedium::SetIsRemote_Impl()
break;
}
- // Da Dateien, die Remote geschrieben werden zur Uebertragung auch
- // gelesen werden koennen muessen
+ // As files that are written to the remote transmission must also be able
+ // to be read.
if( bRemote )
nStorOpenMode |= STREAM_READ;
}
@@ -3197,7 +3197,7 @@ sal_uInt16 SfxMedium::AddVersion_Impl( util::RevisionTag& rRevision )
{
if ( GetStorage().is() )
{
- // Einen eindeutigen Namen f"ur den Stream ermitteln
+ // To determine a unique name for the stream
SvULongs aLongs;
sal_Int32 nLength = pImp->aVersions.getLength();
for ( sal_Int32 m=0; m<nLength; m++ )
@@ -1365,18 +1365,18 @@ uno::Reference < embed::XStorage > SfxMedium::GetStorage( sal_Bool bCreateTempIf
util::RevisionTag& rTag = pImp->aVersions[nVersion];
{
- // SubStorage f"ur alle Versionen "offnen
+ // Open SubStorage for all versions
uno::Reference < embed::XStorage > xSub = pImp->xStorage->openStorageElement( DEFINE_CONST_UNICODE( "Versions" ),
embed::ElementModes::READ );